# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ProcessorResponseCode(object):

    """Implementation of the 'Processor Response Code' enum.

    Processor response code for the non-PayPal payment processor errors.

    Attributes:
        ENUM_0000: TODO: type description here.
        ENUM_00N7: TODO: type description here.
        ENUM_0100: TODO: type description here.
        ENUM_0390: TODO: type description here.
        ENUM_0500: TODO: type description here.
        ENUM_0580: TODO: type description here.
        ENUM_0800: TODO: type description here.
        ENUM_0880: TODO: type description here.
        ENUM_0890: TODO: type description here.
        ENUM_0960: TODO: type description here.
        ENUM_0R00: TODO: type description here.
        ENUM_1000: TODO: type description here.
        ENUM_10BR: TODO: type description here.
        ENUM_1300: TODO: type description here.
        ENUM_1310: TODO: type description here.
        ENUM_1312: TODO: type description here.
        ENUM_1317: TODO: type description here.
        ENUM_1320: TODO: type description here.
        ENUM_1330: TODO: type description here.
        ENUM_1335: TODO: type description here.
        ENUM_1340: TODO: type description here.
        ENUM_1350: TODO: type description here.
        ENUM_1352: TODO: type description here.
        ENUM_1360: TODO: type description here.
        ENUM_1370: TODO: type description here.
        ENUM_1380: TODO: type description here.
        ENUM_1382: TODO: type description here.
        ENUM_1384: TODO: type description here.
        ENUM_1390: TODO: type description here.
        ENUM_1393: TODO: type description here.
        ENUM_5100: TODO: type description here.
        ENUM_5110: TODO: type description here.
        ENUM_5120: TODO: type description here.
        ENUM_5130: TODO: type description here.
        ENUM_5135: TODO: type description here.
        ENUM_5140: TODO: type description here.
        ENUM_5150: TODO: type description here.
        ENUM_5160: TODO: type description here.
        ENUM_5170: TODO: type description here.
        ENUM_5180: TODO: type description here.
        ENUM_5190: TODO: type description here.
        ENUM_5200: TODO: type description here.
        ENUM_5210: TODO: type description here.
        ENUM_5400: TODO: type description here.
        ENUM_5500: TODO: type description here.
        ENUM_5650: TODO: type description here.
        ENUM_5700: TODO: type description here.
        ENUM_5710: TODO: type description here.
        ENUM_5800: TODO: type description here.
        ENUM_5900: TODO: type description here.
        ENUM_5910: TODO: type description here.
        ENUM_5920: TODO: type description here.
        ENUM_5930: TODO: type description here.
        ENUM_5950: TODO: type description here.
        ENUM_6300: TODO: type description here.
        ENUM_7600: TODO: type description here.
        ENUM_7700: TODO: type description here.
        ENUM_7710: TODO: type description here.
        ENUM_7800: TODO: type description here.
        ENUM_7900: TODO: type description here.
        ENUM_8000: TODO: type description here.
        ENUM_8010: TODO: type description here.
        ENUM_8020: TODO: type description here.
        ENUM_8030: TODO: type description here.
        ENUM_8100: TODO: type description here.
        ENUM_8110: TODO: type description here.
        ENUM_8220: TODO: type description here.
        ENUM_9100: TODO: type description here.
        ENUM_9500: TODO: type description here.
        ENUM_9510: TODO: type description here.
        ENUM_9520: TODO: type description here.
        ENUM_9530: TODO: type description here.
        ENUM_9540: TODO: type description here.
        ENUM_9600: TODO: type description here.
        PCNR: TODO: type description here.
        PCVV: TODO: type description here.
        PP06: TODO: type description here.
        PPRN: TODO: type description here.
        PPAD: TODO: type description here.
        PPAB: TODO: type description here.
        PPAE: TODO: type description here.
        PPAG: TODO: type description here.
        PPAI: TODO: type description here.
        PPAR: TODO: type description here.
        PPAU: TODO: type description here.
        PPAV: TODO: type description here.
        PPAX: TODO: type description here.
        PPBG: TODO: type description here.
        PPC2: TODO: type description here.
        PPCE: TODO: type description here.
        PPCO: TODO: type description here.
        PPCR: TODO: type description here.
        PPCT: TODO: type description here.
        PPCU: TODO: type description here.
        PPD3: TODO: type description here.
        PPDC: TODO: type description here.
        PPDI: TODO: type description here.
        PPDV: TODO: type description here.
        PPDT: TODO: type description here.
        PPEF: TODO: type description here.
        PPEL: TODO: type description here.
        PPER: TODO: type description here.
        PPEX: TODO: type description here.
        PPFE: TODO: type description here.
        PPFI: TODO: type description here.
        PPFR: TODO: type description here.
        PPFV: TODO: type description here.
        PPGR: TODO: type description here.
        PPH1: TODO: type description here.
        PPIF: TODO: type description here.
        PPII: TODO: type description here.
        PPIM: TODO: type description here.
        PPIT: TODO: type description here.
        PPLR: TODO: type description here.
        PPLS: TODO: type description here.
        PPMB: TODO: type description here.
        PPMC: TODO: type description here.
        PPMD: TODO: type description here.
        PPNC: TODO: type description here.
        PPNL: TODO: type description here.
        PPNM: TODO: type description here.
        PPNT: TODO: type description here.
        PPPH: TODO: type description here.
        PPPI: TODO: type description here.
        PPPM: TODO: type description here.
        PPQC: TODO: type description here.
        PPRE: TODO: type description here.
        PPRF: TODO: type description here.
        PPRR: TODO: type description here.
        PPS0: TODO: type description here.
        PPS1: TODO: type description here.
        PPS2: TODO: type description here.
        PPS3: TODO: type description here.
        PPS4: TODO: type description here.
        PPS5: TODO: type description here.
        PPS6: TODO: type description here.
        PPSC: TODO: type description here.
        PPSD: TODO: type description here.
        PPSE: TODO: type description here.
        PPTE: TODO: type description here.
        PPTF: TODO: type description here.
        PPTI: TODO: type description here.
        PPTR: TODO: type description here.
        PPTT: TODO: type description here.
        PPTV: TODO: type description here.
        PPUA: TODO: type description here.
        PPUC: TODO: type description here.
        PPUE: TODO: type description here.
        PPUI: TODO: type description here.
        PPUP: TODO: type description here.
        PPUR: TODO: type description here.
        PPVC: TODO: type description here.
        PPVE: TODO: type description here.
        PPVT: TODO: type description here.

    """
    ENUM_0000 = '0000'

    ENUM_00N7 = '00N7'

    ENUM_0100 = '0100'

    ENUM_0390 = '0390'

    ENUM_0500 = '0500'

    ENUM_0580 = '0580'

    ENUM_0800 = '0800'

    ENUM_0880 = '0880'

    ENUM_0890 = '0890'

    ENUM_0960 = '0960'

    ENUM_0R00 = '0R00'

    ENUM_1000 = '1000'

    ENUM_10BR = '10BR'

    ENUM_1300 = '1300'

    ENUM_1310 = '1310'

    ENUM_1312 = '1312'

    ENUM_1317 = '1317'

    ENUM_1320 = '1320'

    ENUM_1330 = '1330'

    ENUM_1335 = '1335'

    ENUM_1340 = '1340'

    ENUM_1350 = '1350'

    ENUM_1352 = '1352'

    ENUM_1360 = '1360'

    ENUM_1370 = '1370'

    ENUM_1380 = '1380'

    ENUM_1382 = '1382'

    ENUM_1384 = '1384'

    ENUM_1390 = '1390'

    ENUM_1393 = '1393'

    ENUM_5100 = '5100'

    ENUM_5110 = '5110'

    ENUM_5120 = '5120'

    ENUM_5130 = '5130'

    ENUM_5135 = '5135'

    ENUM_5140 = '5140'

    ENUM_5150 = '5150'

    ENUM_5160 = '5160'

    ENUM_5170 = '5170'

    ENUM_5180 = '5180'

    ENUM_5190 = '5190'

    ENUM_5200 = '5200'

    ENUM_5210 = '5210'

    ENUM_5400 = '5400'

    ENUM_5500 = '5500'

    ENUM_5650 = '5650'

    ENUM_5700 = '5700'

    ENUM_5710 = '5710'

    ENUM_5800 = '5800'

    ENUM_5900 = '5900'

    ENUM_5910 = '5910'

    ENUM_5920 = '5920'

    ENUM_5930 = '5930'

    ENUM_5950 = '5950'

    ENUM_6300 = '6300'

    ENUM_7600 = '7600'

    ENUM_7700 = '7700'

    ENUM_7710 = '7710'

    ENUM_7800 = '7800'

    ENUM_7900 = '7900'

    ENUM_8000 = '8000'

    ENUM_8010 = '8010'

    ENUM_8020 = '8020'

    ENUM_8030 = '8030'

    ENUM_8100 = '8100'

    ENUM_8110 = '8110'

    ENUM_8220 = '8220'

    ENUM_9100 = '9100'

    ENUM_9500 = '9500'

    ENUM_9510 = '9510'

    ENUM_9520 = '9520'

    ENUM_9530 = '9530'

    ENUM_9540 = '9540'

    ENUM_9600 = '9600'

    PCNR = 'PCNR'

    PCVV = 'PCVV'

    PP06 = 'PP06'

    PPRN = 'PPRN'

    PPAD = 'PPAD'

    PPAB = 'PPAB'

    PPAE = 'PPAE'

    PPAG = 'PPAG'

    PPAI = 'PPAI'

    PPAR = 'PPAR'

    PPAU = 'PPAU'

    PPAV = 'PPAV'

    PPAX = 'PPAX'

    PPBG = 'PPBG'

    PPC2 = 'PPC2'

    PPCE = 'PPCE'

    PPCO = 'PPCO'

    PPCR = 'PPCR'

    PPCT = 'PPCT'

    PPCU = 'PPCU'

    PPD3 = 'PPD3'

    PPDC = 'PPDC'

    PPDI = 'PPDI'

    PPDV = 'PPDV'

    PPDT = 'PPDT'

    PPEF = 'PPEF'

    PPEL = 'PPEL'

    PPER = 'PPER'

    PPEX = 'PPEX'

    PPFE = 'PPFE'

    PPFI = 'PPFI'

    PPFR = 'PPFR'

    PPFV = 'PPFV'

    PPGR = 'PPGR'

    PPH1 = 'PPH1'

    PPIF = 'PPIF'

    PPII = 'PPII'

    PPIM = 'PPIM'

    PPIT = 'PPIT'

    PPLR = 'PPLR'

    PPLS = 'PPLS'

    PPMB = 'PPMB'

    PPMC = 'PPMC'

    PPMD = 'PPMD'

    PPNC = 'PPNC'

    PPNL = 'PPNL'

    PPNM = 'PPNM'

    PPNT = 'PPNT'

    PPPH = 'PPPH'

    PPPI = 'PPPI'

    PPPM = 'PPPM'

    PPQC = 'PPQC'

    PPRE = 'PPRE'

    PPRF = 'PPRF'

    PPRR = 'PPRR'

    PPS0 = 'PPS0'

    PPS1 = 'PPS1'

    PPS2 = 'PPS2'

    PPS3 = 'PPS3'

    PPS4 = 'PPS4'

    PPS5 = 'PPS5'

    PPS6 = 'PPS6'

    PPSC = 'PPSC'

    PPSD = 'PPSD'

    PPSE = 'PPSE'

    PPTE = 'PPTE'

    PPTF = 'PPTF'

    PPTI = 'PPTI'

    PPTR = 'PPTR'

    PPTT = 'PPTT'

    PPTV = 'PPTV'

    PPUA = 'PPUA'

    PPUC = 'PPUC'

    PPUE = 'PPUE'

    PPUI = 'PPUI'

    PPUP = 'PPUP'

    PPUR = 'PPUR'

    PPVC = 'PPVC'

    PPVE = 'PPVE'

    PPVT = 'PPVT'

