# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoredPaymentSourcePaymentType(object):

    """Implementation of the 'Stored Payment Source Payment Type' enum.

    Indicates the type of the stored payment_source payment.

    Attributes:
        ONE_TIME: TODO: type description here.
        RECURRING: TODO: type description here.
        UNSCHEDULED: TODO: type description here.

    """
    ONE_TIME = 'ONE_TIME'

    RECURRING = 'RECURRING'

    UNSCHEDULED = 'UNSCHEDULED'

