# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayeePaymentMethodPreference(object):

    """Implementation of the 'Payee Payment Method Preference' enum.

    The merchant-preferred payment methods.

    Attributes:
        UNRESTRICTED: TODO: type description here.
        IMMEDIATE_PAYMENT_REQUIRED: TODO: type description here.

    """
    UNRESTRICTED = 'UNRESTRICTED'

    IMMEDIATE_PAYMENT_REQUIRED = 'IMMEDIATE_PAYMENT_REQUIRED'

