# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenUsagePattern(object):

    """Implementation of the 'PayPal Payment Token Usage Pattern' enum.

    Expected business/pricing model for the billing agreement.

    Attributes:
        IMMEDIATE: TODO: type description here.
        DEFERRED: TODO: type description here.
        RECURRING_PREPAID: TODO: type description here.
        RECURRING_POSTPAID: TODO: type description here.
        THRESHOLD_PREPAID: TODO: type description here.
        THRESHOLD_POSTPAID: TODO: type description here.

    """
    IMMEDIATE = 'IMMEDIATE'

    DEFERRED = 'DEFERRED'

    RECURRING_PREPAID = 'RECURRING_PREPAID'

    RECURRING_POSTPAID = 'RECURRING_POSTPAID'

    THRESHOLD_PREPAID = 'THRESHOLD_PREPAID'

    THRESHOLD_POSTPAID = 'THRESHOLD_POSTPAID'

