# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalserversdk.api_helper import APIHelper


class ShippingName(object):

    """Implementation of the 'Shipping Name' model.

    The name of the party.

    Attributes:
        full_name (str): When the party is a person, the party's full name.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "full_name": 'full_name'
    }

    _optionals = [
        'full_name',
    ]

    def __init__(self,
                 full_name=APIHelper.SKIP):
        """Constructor for the ShippingName class"""

        # Initialize members of the class
        if full_name is not APIHelper.SKIP:
            self.full_name = full_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if dictionary is None:
            return None

        # Extract variables from the dictionary
        full_name = dictionary.get("full_name") if dictionary.get("full_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(full_name)
