# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class EnrollmentStatus(object):

    """Implementation of the 'Enrollment Status' enum.

    Status of Authentication eligibility.

    Attributes:
        Y: TODO: type description here.
        N: TODO: type description here.
        U: TODO: type description here.
        B: TODO: type description here.

    """
    Y = 'Y'

    N = 'N'

    U = 'U'

    B = 'B'

