# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DisbursementMode(object):

    """Implementation of the 'Disbursement Mode' enum.

    The funds that are held on behalf of the merchant.

    Attributes:
        INSTANT: TODO: type description here.
        DELAYED: TODO: type description here.

    """
    INSTANT = 'INSTANT'

    DELAYED = 'DELAYED'

