# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardVerificationMethod(object):

    """Implementation of the 'Card Verification Method' enum.

    The method used for card verification.

    Attributes:
        SCA_ALWAYS: TODO: type description here.
        SCA_WHEN_REQUIRED: TODO: type description here.
        ENUM_3D_SECURE: TODO: type description here.
        AVS_CVV: TODO: type description here.

    """
    SCA_ALWAYS = 'SCA_ALWAYS'

    SCA_WHEN_REQUIRED = 'SCA_WHEN_REQUIRED'

    ENUM_3D_SECURE = '3D_SECURE'

    AVS_CVV = 'AVS_CVV'

