# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemCategory(object):

    """Implementation of the 'Item Category' enum.

    The item category type.

    Attributes:
        DIGITAL_GOODS: TODO: type description here.
        PHYSICAL_GOODS: TODO: type description here.
        DONATION: TODO: type description here.

    """
    DIGITAL_GOODS = 'DIGITAL_GOODS'

    PHYSICAL_GOODS = 'PHYSICAL_GOODS'

    DONATION = 'DONATION'

