# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardBrand(object):

    """Implementation of the 'Card Brand' enum.

    The card network or brand. Applies to credit, debit, gift, and payment
    cards.

    Attributes:
        VISA: TODO: type description here.
        MASTERCARD: TODO: type description here.
        DISCOVER: TODO: type description here.
        AMEX: TODO: type description here.
        SOLO: TODO: type description here.
        JCB: TODO: type description here.
        STAR: TODO: type description here.
        DELTA: TODO: type description here.
        SWITCH: TODO: type description here.
        MAESTRO: TODO: type description here.
        CB_NATIONALE: TODO: type description here.
        CONFIGOGA: TODO: type description here.
        CONFIDIS: TODO: type description here.
        ELECTRON: TODO: type description here.
        CETELEM: TODO: type description here.
        CHINA_UNION_PAY: TODO: type description here.
        DINERS: TODO: type description here.
        ELO: TODO: type description here.
        HIPER: TODO: type description here.
        HIPERCARD: TODO: type description here.
        RUPAY: TODO: type description here.
        GE: TODO: type description here.
        SYNCHRONY: TODO: type description here.
        EFTPOS: TODO: type description here.
        UNKNOWN: TODO: type description here.

    """
    VISA = 'VISA'

    MASTERCARD = 'MASTERCARD'

    DISCOVER = 'DISCOVER'

    AMEX = 'AMEX'

    SOLO = 'SOLO'

    JCB = 'JCB'

    STAR = 'STAR'

    DELTA = 'DELTA'

    SWITCH = 'SWITCH'

    MAESTRO = 'MAESTRO'

    CB_NATIONALE = 'CB_NATIONALE'

    CONFIGOGA = 'CONFIGOGA'

    CONFIDIS = 'CONFIDIS'

    ELECTRON = 'ELECTRON'

    CETELEM = 'CETELEM'

    CHINA_UNION_PAY = 'CHINA_UNION_PAY'

    DINERS = 'DINERS'

    ELO = 'ELO'

    HIPER = 'HIPER'

    HIPERCARD = 'HIPERCARD'

    RUPAY = 'RUPAY'

    GE = 'GE'

    SYNCHRONY = 'SYNCHRONY'

    EFTPOS = 'EFTPOS'

    UNKNOWN = 'UNKNOWN'

