# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class GooglePayPaymentMethod(object):

    """Implementation of the 'Google Pay Payment Method' enum.

    The type of the payment credential. Currently, only CARD is supported.

    Attributes:
        CARD: TODO: type description here.

    """
    CARD = 'CARD'

