# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PAResStatus(object):

    """Implementation of the 'PARes Status' enum.

    Transactions status result identifier. The outcome of the issuer's
    authentication.

    Attributes:
        Y: TODO: type description here.
        N: TODO: type description here.
        U: TODO: type description here.
        A: TODO: type description here.
        C: TODO: type description here.
        R: TODO: type description here.
        D: TODO: type description here.
        I: TODO: type description here.

    """
    Y = 'Y'

    N = 'N'

    U = 'U'

    A = 'A'

    C = 'C'

    R = 'R'

    D = 'D'

    I = 'I'

