# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CaptureStatus(object):

    """Implementation of the 'Capture Status' enum.

    The status of the captured payment.

    Attributes:
        COMPLETED: TODO: type description here.
        DECLINED: TODO: type description here.
        PARTIALLY_REFUNDED: TODO: type description here.
        PENDING: TODO: type description here.
        REFUNDED: TODO: type description here.
        FAILED: TODO: type description here.

    """
    COMPLETED = 'COMPLETED'

    DECLINED = 'DECLINED'

    PARTIALLY_REFUNDED = 'PARTIALLY_REFUNDED'

    PENDING = 'PENDING'

    REFUNDED = 'REFUNDED'

    FAILED = 'FAILED'

