# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderApplicationContextShippingPreference(object):

    """Implementation of the 'Order Application Context Shipping Preference' enum.

    DEPRECATED. DEPRECATED. The shipping preference:<ul><li>Displays the
    shipping address to the customer.</li><li>Enables the customer to choose
    an address on the PayPal site.</li><li>Restricts the customer from
    changing the address during the payment-approval process.</li></ul>.  The
    fields in `application_context` are now available in the
    `experience_context` object under the `payment_source` which supports them
    (eg. `payment_source.paypal.experience_context.shipping_preference`).
    Please specify this field in the `experience_context` object instead of
    the `application_context` object.

    Attributes:
        GET_FROM_FILE: TODO: type description here.
        NO_SHIPPING: TODO: type description here.
        SET_PROVIDED_ADDRESS: TODO: type description here.

    """
    GET_FROM_FILE = 'GET_FROM_FILE'

    NO_SHIPPING = 'NO_SHIPPING'

    SET_PROVIDED_ADDRESS = 'SET_PROVIDED_ADDRESS'

