# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AuthorizationStatus(object):

    """Implementation of the 'Authorization Status' enum.

    The status for the authorized payment.

    Attributes:
        CREATED: TODO: type description here.
        CAPTURED: TODO: type description here.
        DENIED: TODO: type description here.
        PARTIALLY_CAPTURED: TODO: type description here.
        VOIDED: TODO: type description here.
        PENDING: TODO: type description here.

    """
    CREATED = 'CREATED'

    CAPTURED = 'CAPTURED'

    DENIED = 'DENIED'

    PARTIALLY_CAPTURED = 'PARTIALLY_CAPTURED'

    VOIDED = 'VOIDED'

    PENDING = 'PENDING'

