# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoredPaymentSourceUsageType(object):

    """Implementation of the 'Stored Payment Source Usage Type' enum.

    Indicates if this is a `first` or `subsequent` payment using a stored
    payment source (also referred to as stored credential or card on file).

    Attributes:
        FIRST: TODO: type description here.
        SUBSEQUENT: TODO: type description here.
        DERIVED: TODO: type description here.

    """
    FIRST = 'FIRST'

    SUBSEQUENT = 'SUBSEQUENT'

    DERIVED = 'DERIVED'

