# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DisputeCategory(object):

    """Implementation of the 'Dispute Category' enum.

    The condition that is covered for the transaction.

    Attributes:
        ITEM_NOT_RECEIVED: TODO: type description here.
        UNAUTHORIZED_TRANSACTION: TODO: type description here.

    """
    ITEM_NOT_RECEIVED = 'ITEM_NOT_RECEIVED'

    UNAUTHORIZED_TRANSACTION = 'UNAUTHORIZED_TRANSACTION'

