# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AVSCode(object):

    """Implementation of the 'AVS Code' enum.

    The address verification code for Visa, Discover, Mastercard, or American
    Express transactions.

    Attributes:
        A: TODO: type description here.
        B: TODO: type description here.
        C: TODO: type description here.
        D: TODO: type description here.
        E: TODO: type description here.
        F: TODO: type description here.
        G: TODO: type description here.
        I: TODO: type description here.
        M: TODO: type description here.
        N: TODO: type description here.
        P: TODO: type description here.
        R: TODO: type description here.
        S: TODO: type description here.
        U: TODO: type description here.
        W: TODO: type description here.
        X: TODO: type description here.
        Y: TODO: type description here.
        Z: TODO: type description here.
        NULL: TODO: type description here.
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """
    A = 'A'

    B = 'B'

    C = 'C'

    D = 'D'

    E = 'E'

    F = 'F'

    G = 'G'

    I = 'I'

    M = 'M'

    N = 'N'

    P = 'P'

    R = 'R'

    S = 'S'

    U = 'U'

    W = 'W'

    X = 'X'

    Y = 'Y'

    Z = 'Z'

    NULL = 'Null'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'

