# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletVaultStatus(object):

    """Implementation of the 'PayPal Wallet Vault Status' enum.

    The vault status.

    Attributes:
        VAULTED: TODO: type description here.
        CREATED: TODO: type description here.
        APPROVED: TODO: type description here.

    """
    VAULTED = 'VAULTED'

    CREATED = 'CREATED'

    APPROVED = 'APPROVED'

