# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TaxIdType(object):

    """Implementation of the 'Tax Id Type' enum.

    The customer's tax ID type.

    Attributes:
        BR_CPF: TODO: type description here.
        BR_CNPJ: TODO: type description here.

    """
    BR_CPF = 'BR_CPF'

    BR_CNPJ = 'BR_CNPJ'

