# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ShippingPreference(object):

    """Implementation of the 'Shipping Preference' enum.

    The location from which the shipping address is derived.

    Attributes:
        GET_FROM_FILE: TODO: type description here.
        NO_SHIPPING: TODO: type description here.
        SET_PROVIDED_ADDRESS: TODO: type description here.

    """
    GET_FROM_FILE = 'GET_FROM_FILE'

    NO_SHIPPING = 'NO_SHIPPING'

    SET_PROVIDED_ADDRESS = 'SET_PROVIDED_ADDRESS'

