# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CheckoutPaymentIntent(object):

    """Implementation of the 'Checkout Payment Intent' enum.

    The intent to either capture payment immediately or authorize a payment
    for an order after order creation.

    Attributes:
        CAPTURE: TODO: type description here.
        AUTHORIZE: TODO: type description here.

    """
    CAPTURE = 'CAPTURE'

    AUTHORIZE = 'AUTHORIZE'

