# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class GooglePayAuthenticationMethod(object):

    """Implementation of the 'Google Pay Authentication Method' enum.

    Authentication Method which is used for the card transaction.

    Attributes:
        PAN_ONLY: TODO: type description here.
        CRYPTOGRAM_3DS: TODO: type description here.

    """
    PAN_ONLY = 'PAN_ONLY'

    CRYPTOGRAM_3DS = 'CRYPTOGRAM_3DS'

