# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ShippingType(object):

    """Implementation of the 'Shipping Type' enum.

    A classification for the method of purchase fulfillment.

    Attributes:
        SHIPPING: TODO: type description here.
        PICKUP: TODO: type description here.
        PICKUP_IN_STORE: TODO: type description here.
        PICKUP_FROM_PERSON: TODO: type description here.

    """
    SHIPPING = 'SHIPPING'

    PICKUP = 'PICKUP'

    PICKUP_IN_STORE = 'PICKUP_IN_STORE'

    PICKUP_FROM_PERSON = 'PICKUP_FROM_PERSON'

