# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class LiabilityShiftIndicator(object):

    """Implementation of the 'Liability Shift Indicator' enum.

    Liability shift indicator. The outcome of the issuer's authentication.

    Attributes:
        NO: TODO: type description here.
        POSSIBLE: TODO: type description here.
        UNKNOWN: TODO: type description here.

    """
    NO = 'NO'

    POSSIBLE = 'POSSIBLE'

    UNKNOWN = 'UNKNOWN'

