# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenUsageType(object):

    """Implementation of the 'PayPal Payment Token Usage Type' enum.

    The usage type associated with the PayPal payment token.

    Attributes:
        MERCHANT: TODO: type description here.
        PLATFORM: TODO: type description here.

    """
    MERCHANT = 'MERCHANT'

    PLATFORM = 'PLATFORM'

