# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ApplePayPaymentDataType(object):

    """Implementation of the 'Apple Pay Payment Data Type' enum.

    Indicates the type of payment data passed, in case of Non China the
    payment data is 3DSECURE and for China it is EMV.

    Attributes:
        ENUM_3DSECURE: TODO: type description here.
        EMV: TODO: type description here.

    """
    ENUM_3DSECURE = '3DSECURE'

    EMV = 'EMV'

