# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AuthorizationIncompleteReason(object):

    """Implementation of the 'Authorization Incomplete Reason' enum.

    The reason why the authorized status is `PENDING`.

    Attributes:
        PENDING_REVIEW: TODO: type description here.
        DECLINED_BY_RISK_FRAUD_FILTERS: TODO: type description here.

    """
    PENDING_REVIEW = 'PENDING_REVIEW'

    DECLINED_BY_RISK_FRAUD_FILTERS = 'DECLINED_BY_RISK_FRAUD_FILTERS'

