# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CVVCode(object):

    """Implementation of the 'CVV Code' enum.

    The card verification value code for for Visa, Discover, Mastercard, or
    American Express.

    Attributes:
        E: TODO: type description here.
        I: TODO: type description here.
        M: TODO: type description here.
        N: TODO: type description here.
        P: TODO: type description here.
        S: TODO: type description here.
        U: TODO: type description here.
        X: TODO: type description here.
        ENUM_ALL OTHERS: TODO: type description here.
        ENUM_0: TODO: type description here.
        ENUM_1: TODO: type description here.
        ENUM_2: TODO: type description here.
        ENUM_3: TODO: type description here.
        ENUM_4: TODO: type description here.

    """
    E = 'E'

    I = 'I'

    M = 'M'

    N = 'N'

    P = 'P'

    S = 'S'

    U = 'U'

    X = 'X'

    ENUM_ALL_OTHERS = 'All others'

    ENUM_0 = '0'

    ENUM_1 = '1'

    ENUM_2 = '2'

    ENUM_3 = '3'

    ENUM_4 = '4'

