# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TokenRequestType(object):

    """Implementation of the 'Token Request Type' enum.

    The tokenization method that generated the ID.

    Attributes:
        SETUP_TOKEN: TODO: type description here.
        BILLING_AGREEMENT: TODO: type description here.

    """
    SETUP_TOKEN = 'SETUP_TOKEN'

    BILLING_AGREEMENT = 'BILLING_AGREEMENT'

