# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ECIFlag(object):

    """Implementation of the 'ECI Flag' enum.

    Electronic Commerce Indicator (ECI). The ECI value is part of the 2 data
    elements that indicate the transaction was processed electronically. This
    should be passed on the authorization transaction to the
    Gateway/Processor.

    Attributes:
        MASTERCARD_NON_3D_SECURE_TRANSACTION: TODO: type description here.
        MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION: TODO: type
            description here.
        MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION: TODO: type description
            here.
        FULLY_AUTHENTICATED_TRANSACTION: TODO: type description here.
        ATTEMPTED_AUTHENTICATION_TRANSACTION: TODO: type description here.
        NON_3D_SECURE_TRANSACTION: TODO: type description here.

    """
    MASTERCARD_NON_3D_SECURE_TRANSACTION = 'MASTERCARD_NON_3D_SECURE_TRANSACTION'

    MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION = 'MASTERCARD_ATTEMPTED_AUTHENTICATION_TRANSACTION'

    MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION = 'MASTERCARD_FULLY_AUTHENTICATED_TRANSACTION'

    FULLY_AUTHENTICATED_TRANSACTION = 'FULLY_AUTHENTICATED_TRANSACTION'

    ATTEMPTED_AUTHENTICATION_TRANSACTION = 'ATTEMPTED_AUTHENTICATION_TRANSACTION'

    NON_3D_SECURE_TRANSACTION = 'NON_3D_SECURE_TRANSACTION'

