# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletAccountVerificationStatus(object):

    """Implementation of the 'PayPal Wallet Account Verification Status' enum.

    The account status indicates whether the buyer has verified the financial
    details associated with their PayPal account.

    Attributes:
        VERIFIED: TODO: type description here.
        UNVERIFIED: TODO: type description here.

    """
    VERIFIED = 'VERIFIED'

    UNVERIFIED = 'UNVERIFIED'

