# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalExperienceUserAction(object):

    """Implementation of the 'PayPal Experience User Action' enum.

    Configures a <strong>Continue</strong> or <strong>Pay Now</strong>
    checkout flow.

    Attributes:
        CONTINUE: TODO: type description here.
        PAY_NOW: TODO: type description here.

    """
    CONTINUE = 'CONTINUE'

    PAY_NOW = 'PAY_NOW'

