# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SellerProtectionStatus(object):

    """Implementation of the 'Seller Protection Status' enum.

    Indicates whether the transaction is eligible for seller protection. For
    information, see [PayPal Seller Protection for
    Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-protection
    ).

    Attributes:
        ELIGIBLE: TODO: type description here.
        PARTIALLY_ELIGIBLE: TODO: type description here.
        NOT_ELIGIBLE: TODO: type description here.

    """
    ELIGIBLE = 'ELIGIBLE'

    PARTIALLY_ELIGIBLE = 'PARTIALLY_ELIGIBLE'

    NOT_ELIGIBLE = 'NOT_ELIGIBLE'

