# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardType(object):

    """Implementation of the 'Card Type' enum.

    Type of card. i.e Credit, Debit and so on.

    Attributes:
        CREDIT: TODO: type description here.
        DEBIT: TODO: type description here.
        PREPAID: TODO: type description here.
        STORE: TODO: type description here.
        UNKNOWN: TODO: type description here.

    """
    CREDIT = 'CREDIT'

    DEBIT = 'DEBIT'

    PREPAID = 'PREPAID'

    STORE = 'STORE'

    UNKNOWN = 'UNKNOWN'

