# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PhoneType(object):

    """Implementation of the 'Phone Type' enum.

    The phone type.

    Attributes:
        FAX: TODO: type description here.
        HOME: TODO: type description here.
        MOBILE: TODO: type description here.
        OTHER: TODO: type description here.
        PAGER: TODO: type description here.

    """
    FAX = 'FAX'

    HOME = 'HOME'

    MOBILE = 'MOBILE'

    OTHER = 'OTHER'

    PAGER = 'PAGER'

