# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class LinkHTTPMethod(object):

    """Implementation of the 'Link HTTP Method' enum.

    The HTTP method required to make the related call.

    Attributes:
        GET: TODO: type description here.
        POST: TODO: type description here.
        PUT: TODO: type description here.
        DELETE: TODO: type description here.
        HEAD: TODO: type description here.
        CONNECT: TODO: type description here.
        OPTIONS: TODO: type description here.
        PATCH: TODO: type description here.

    """
    GET = 'GET'

    POST = 'POST'

    PUT = 'PUT'

    DELETE = 'DELETE'

    HEAD = 'HEAD'

    CONNECT = 'CONNECT'

    OPTIONS = 'OPTIONS'

    PATCH = 'PATCH'

