# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderApplicationContextLandingPage(object):

    """Implementation of the 'Order Application Context Landing Page' enum.

    DEPRECATED. DEPRECATED. The type of landing page to show on the PayPal
    site for customer checkout.  The fields in `application_context` are now
    available in the `experience_context` object under the `payment_source`
    which supports them (eg.
    `payment_source.paypal.experience_context.landing_page`). Please specify
    this field in the `experience_context` object instead of the
    `application_context` object.

    Attributes:
        LOGIN: TODO: type description here.
        BILLING: TODO: type description here.
        NO_PREFERENCE: TODO: type description here.

    """
    LOGIN = 'LOGIN'

    BILLING = 'BILLING'

    NO_PREFERENCE = 'NO_PREFERENCE'

