# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ProcessingInstruction(object):

    """Implementation of the 'Processing Instruction' enum.

    The instruction to process an order.

    Attributes:
        ORDER_COMPLETE_ON_PAYMENT_APPROVAL: TODO: type description here.
        NO_INSTRUCTION: TODO: type description here.

    """
    ORDER_COMPLETE_ON_PAYMENT_APPROVAL = 'ORDER_COMPLETE_ON_PAYMENT_APPROVAL'

    NO_INSTRUCTION = 'NO_INSTRUCTION'

