# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PatchOp(object):

    """Implementation of the 'Patch Op' enum.

    The operation.

    Attributes:
        ADD: TODO: type description here.
        REMOVE: TODO: type description here.
        REPLACE: TODO: type description here.
        MOVE: TODO: type description here.
        COPY: TODO: type description here.
        TEST: TODO: type description here.

    """
    ADD = 'add'

    REMOVE = 'remove'

    REPLACE = 'replace'

    MOVE = 'move'

    COPY = 'copy'

    TEST = 'test'

