# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RefundStatus(object):

    """Implementation of the 'Refund Status' enum.

    The status of the refund.

    Attributes:
        CANCELLED: TODO: type description here.
        FAILED: TODO: type description here.
        PENDING: TODO: type description here.
        COMPLETED: TODO: type description here.

    """
    CANCELLED = 'CANCELLED'

    FAILED = 'FAILED'

    PENDING = 'PENDING'

    COMPLETED = 'COMPLETED'

