# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CaptureIncompleteReason(object):

    """Implementation of the 'Capture Incomplete Reason' enum.

    The reason why the captured payment status is `PENDING` or `DENIED`.

    Attributes:
        BUYER_COMPLAINT: TODO: type description here.
        CHARGEBACK: TODO: type description here.
        ECHECK: TODO: type description here.
        INTERNATIONAL_WITHDRAWAL: TODO: type description here.
        OTHER: TODO: type description here.
        PENDING_REVIEW: TODO: type description here.
        RECEIVING_PREFERENCE_MANDATES_MANUAL_ACTION: TODO: type description
            here.
        REFUNDED: TODO: type description here.
        TRANSACTION_APPROVED_AWAITING_FUNDING: TODO: type description here.
        UNILATERAL: TODO: type description here.
        VERIFICATION_REQUIRED: TODO: type description here.
        DECLINED_BY_RISK_FRAUD_FILTERS: TODO: type description here.

    """
    BUYER_COMPLAINT = 'BUYER_COMPLAINT'

    CHARGEBACK = 'CHARGEBACK'

    ECHECK = 'ECHECK'

    INTERNATIONAL_WITHDRAWAL = 'INTERNATIONAL_WITHDRAWAL'

    OTHER = 'OTHER'

    PENDING_REVIEW = 'PENDING_REVIEW'

    RECEIVING_PREFERENCE_MANDATES_MANUAL_ACTION = 'RECEIVING_PREFERENCE_MANDATES_MANUAL_ACTION'

    REFUNDED = 'REFUNDED'

    TRANSACTION_APPROVED_AWAITING_FUNDING = 'TRANSACTION_APPROVED_AWAITING_FUNDING'

    UNILATERAL = 'UNILATERAL'

    VERIFICATION_REQUIRED = 'VERIFICATION_REQUIRED'

    DECLINED_BY_RISK_FRAUD_FILTERS = 'DECLINED_BY_RISK_FRAUD_FILTERS'

