# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreInVaultInstruction(object):

    """Implementation of the 'Store In Vault Instruction' enum.

    Defines how and when the payment source gets vaulted.

    Attributes:
        ON_SUCCESS: TODO: type description here.

    """
    ON_SUCCESS = 'ON_SUCCESS'

