# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ShipmentCarrier(object):

    """Implementation of the 'Shipment Carrier' enum.

    The carrier for the shipment. Some carriers have a global version as well
    as local subsidiaries. The subsidiaries are repeated over many countries
    and might also have an entry in the global list. Choose the carrier for
    your country. If the carrier is not available for your country, choose the
    global version of the carrier. If your carrier name is not in the list,
    set `carrier` to `OTHER` and set carrier name in `carrier_name_other`. For
    allowed values, see <a
    href="/docs/tracking/reference/carriers/">Carriers</a>.

    Attributes:
        DPD_RU: TODO: type description here.
        BG_BULGARIAN_POST: TODO: type description here.
        KR_KOREA_POST: TODO: type description here.
        ZA_COURIERIT: TODO: type description here.
        FR_EXAPAQ: TODO: type description here.
        ARE_EMIRATES_POST: TODO: type description here.
        GAC: TODO: type description here.
        GEIS: TODO: type description here.
        SF_EX: TODO: type description here.
        PAGO: TODO: type description here.
        MYHERMES: TODO: type description here.
        DIAMOND_EUROGISTICS: TODO: type description here.
        CORPORATECOURIERS_WEBHOOK: TODO: type description here.
        BOND: TODO: type description here.
        OMNIPARCEL: TODO: type description here.
        SK_POSTA: TODO: type description here.
        PUROLATOR: TODO: type description here.
        FETCHR_WEBHOOK: TODO: type description here.
        THEDELIVERYGROUP: TODO: type description here.
        CELLO_SQUARE: TODO: type description here.
        TARRIVE: TODO: type description here.
        COLLIVERY: TODO: type description here.
        MAINFREIGHT: TODO: type description here.
        IND_FIRSTFLIGHT: TODO: type description here.
        ACSWORLDWIDE: TODO: type description here.
        AMSTAN: TODO: type description here.
        OKAYPARCEL: TODO: type description here.
        ENVIALIA_REFERENCE: TODO: type description here.
        SEUR_ES: TODO: type description here.
        CONTINENTAL: TODO: type description here.
        FDSEXPRESS: TODO: type description here.
        AMAZON_FBA_SWISHIP: TODO: type description here.
        WYNGS: TODO: type description here.
        DHL_ACTIVE_TRACING: TODO: type description here.
        ZYLLEM: TODO: type description here.
        RUSTON: TODO: type description here.
        XPOST: TODO: type description here.
        CORREOS_ES: TODO: type description here.
        DHL_FR: TODO: type description here.
        PAN_ASIA: TODO: type description here.
        BRT_IT: TODO: type description here.
        SRE_KOREA: TODO: type description here.
        SPEEDEE: TODO: type description here.
        TNT_UK: TODO: type description here.
        VENIPAK: TODO: type description here.
        SHREENANDANCOURIER: TODO: type description here.
        CROSHOT: TODO: type description here.
        NIPOST_NG: TODO: type description here.
        EPST_GLBL: TODO: type description here.
        NEWGISTICS: TODO: type description here.
        POST_SLOVENIA: TODO: type description here.
        JERSEY_POST: TODO: type description here.
        BOMBINOEXP: TODO: type description here.
        WMG: TODO: type description here.
        XQ_EXPRESS: TODO: type description here.
        FURDECO: TODO: type description here.
        LHT_EXPRESS: TODO: type description here.
        SOUTH_AFRICAN_POST_OFFICE: TODO: type description here.
        SPOTON: TODO: type description here.
        DIMERCO: TODO: type description here.
        CYPRUS_POST_CYP: TODO: type description here.
        ABCUSTOM: TODO: type description here.
        IND_DELIVREE: TODO: type description here.
        CN_BESTEXPRESS: TODO: type description here.
        DX_SFTP: TODO: type description here.
        PICKUPP_MYS: TODO: type description here.
        FMX: TODO: type description here.
        HELLMANN: TODO: type description here.
        SHIP_IT_ASIA: TODO: type description here.
        KERRY_ECOMMERCE: TODO: type description here.
        FRETERAPIDO: TODO: type description here.
        PITNEY_BOWES: TODO: type description here.
        XPRESSEN_DK: TODO: type description here.
        SEUR_SP_API: TODO: type description here.
        DELIVERYONTIME: TODO: type description here.
        JINSUNG: TODO: type description here.
        TRANS_KARGO: TODO: type description here.
        SWISHIP_DE: TODO: type description here.
        IVOY_WEBHOOK: TODO: type description here.
        AIRMEE_WEBHOOK: TODO: type description here.
        DHL_BENELUX: TODO: type description here.
        FIRSTMILE: TODO: type description here.
        FASTWAY_IR: TODO: type description here.
        HH_EXP: TODO: type description here.
        MYS_MYPOST_ONLINE: TODO: type description here.
        TNT_NL: TODO: type description here.
        TIPSA: TODO: type description here.
        TAQBIN_MY: TODO: type description here.
        KGMHUB: TODO: type description here.
        INTEXPRESS: TODO: type description here.
        OVERSE_EXP: TODO: type description here.
        ONECLICK: TODO: type description here.
        ROADRUNNER_FREIGHT: TODO: type description here.
        GLS_CROTIA: TODO: type description here.
        MRW_FTP: TODO: type description here.
        BLUEX: TODO: type description here.
        DYLT: TODO: type description here.
        DPD_IR: TODO: type description here.
        SIN_GLBL: TODO: type description here.
        TUFFNELLS_REFERENCE: TODO: type description here.
        CJPACKET: TODO: type description here.
        MILKMAN: TODO: type description here.
        ASIGNA: TODO: type description here.
        ONEWORLDEXPRESS: TODO: type description here.
        ROYAL_MAIL: TODO: type description here.
        VIA_EXPRESS: TODO: type description here.
        TIGFREIGHT: TODO: type description here.
        ZTO_EXPRESS: TODO: type description here.
        TWO_GO: TODO: type description here.
        IML: TODO: type description here.
        INTEL_VALLEY: TODO: type description here.
        EFS: TODO: type description here.
        UK_UK_MAIL: TODO: type description here.
        RAM: TODO: type description here.
        ALLIEDEXPRESS: TODO: type description here.
        APC_OVERNIGHT: TODO: type description here.
        SHIPPIT: TODO: type description here.
        TFM: TODO: type description here.
        M_XPRESS: TODO: type description here.
        HDB_BOX: TODO: type description here.
        CLEVY_LINKS: TODO: type description here.
        IBEONE: TODO: type description here.
        FIEGE_NL: TODO: type description here.
        KWE_GLOBAL: TODO: type description here.
        CTC_EXPRESS: TODO: type description here.
        LAO_POST: TODO: type description here.
        AMAZON: TODO: type description here.
        MORE_LINK: TODO: type description here.
        JX: TODO: type description here.
        EASY_MAIL: TODO: type description here.
        ADUIEPYLE: TODO: type description here.
        GB_PANTHER: TODO: type description here.
        EXPRESSSALE: TODO: type description here.
        SG_DETRACK: TODO: type description here.
        TRUNKRS_WEBHOOK: TODO: type description here.
        MATDESPATCH: TODO: type description here.
        DICOM: TODO: type description here.
        MBW: TODO: type description here.
        KHM_CAMBODIA_POST: TODO: type description here.
        SINOTRANS: TODO: type description here.
        BRT_IT_PARCELID: TODO: type description here.
        DHL_SUPPLY_CHAIN: TODO: type description here.
        DHL_PL: TODO: type description here.
        TOPYOU: TODO: type description here.
        PALEXPRESS: TODO: type description here.
        DHL_SG: TODO: type description here.
        CN_WEDO: TODO: type description here.
        FULFILLME: TODO: type description here.
        DPD_DELISTRACK: TODO: type description here.
        UPS_REFERENCE: TODO: type description here.
        CARIBOU: TODO: type description here.
        LOCUS_WEBHOOK: TODO: type description here.
        DSV: TODO: type description here.
        CN_GOFLY: TODO: type description here.
        P2P_TRC: TODO: type description here.
        DIRECTPARCELS: TODO: type description here.
        NOVA_POSHTA_INT: TODO: type description here.
        FEDEX_POLAND: TODO: type description here.
        CN_JCEX: TODO: type description here.
        FAR_INTERNATIONAL: TODO: type description here.
        IDEXPRESS: TODO: type description here.
        GANGBAO: TODO: type description here.
        NEWAY: TODO: type description here.
        POSTNL_INT_3_S: TODO: type description here.
        RPX_ID: TODO: type description here.
        DESIGNERTRANSPORT_WEBHOOK: TODO: type description here.
        GLS_SLOVEN: TODO: type description here.
        PARCELLED_IN: TODO: type description here.
        GSI_EXPRESS: TODO: type description here.
        CON_WAY: TODO: type description here.
        BROUWER_TRANSPORT: TODO: type description here.
        CPEX: TODO: type description here.
        ISRAEL_POST: TODO: type description here.
        DTDC_IN: TODO: type description here.
        PTT_POST: TODO: type description here.
        XDE_WEBHOOK: TODO: type description here.
        TOLOS: TODO: type description here.
        GIAO_HANG: TODO: type description here.
        GEODIS_ESPACE: TODO: type description here.
        MAGYAR_HU: TODO: type description here.
        DOORDASH_WEBHOOK: TODO: type description here.
        TIKI_ID: TODO: type description here.
        CJ_HK_INTERNATIONAL: TODO: type description here.
        STAR_TRACK_EXPRESS: TODO: type description here.
        HELTHJEM: TODO: type description here.
        SFB2C: TODO: type description here.
        FREIGHTQUOTE: TODO: type description here.
        LANDMARK_GLOBAL_REFERENCE: TODO: type description here.
        PARCEL2GO: TODO: type description here.
        DELNEXT: TODO: type description here.
        RCL: TODO: type description here.
        CGS_EXPRESS: TODO: type description here.
        HK_POST: TODO: type description here.
        SAP_EXPRESS: TODO: type description here.
        PARCELPOST_SG: TODO: type description here.
        HERMES: TODO: type description here.
        IND_SAFEEXPRESS: TODO: type description here.
        TOPHATTEREXPRESS: TODO: type description here.
        MGLOBAL: TODO: type description here.
        AVERITT: TODO: type description here.
        LEADER: TODO: type description here.
        _2EBOX: TODO: type description here.
        SG_SPEEDPOST: TODO: type description here.
        DBSCHENKER_SE: TODO: type description here.
        ISR_POST_DOMESTIC: TODO: type description here.
        BESTWAYPARCEL: TODO: type description here.
        ASENDIA_DE: TODO: type description here.
        NIGHTLINE_UK: TODO: type description here.
        TAQBIN_SG: TODO: type description here.
        TCK_EXPRESS: TODO: type description here.
        ENDEAVOUR_DELIVERY: TODO: type description here.
        NANJINGWOYUAN: TODO: type description here.
        HEPPNER_FR: TODO: type description here.
        EMPS_CN: TODO: type description here.
        FONSEN: TODO: type description here.
        PICKRR: TODO: type description here.
        APC_OVERNIGHT_CONNUM: TODO: type description here.
        STAR_TRACK_NEXT_FLIGHT: TODO: type description here.
        DAJIN: TODO: type description here.
        UPS_FREIGHT: TODO: type description here.
        POSTA_PLUS: TODO: type description here.
        CEVA: TODO: type description here.
        ANSERX: TODO: type description here.
        JS_EXPRESS: TODO: type description here.
        PADTF: TODO: type description here.
        UPS_MAIL_INNOVATIONS: TODO: type description here.
        EZSHIP: TODO: type description here.
        SYPOST: TODO: type description here.
        AMAZON_SHIP_MCF: TODO: type description here.
        YUSEN: TODO: type description here.
        BRING: TODO: type description here.
        SDA_IT: TODO: type description here.
        GBA: TODO: type description here.
        NEWEGGEXPRESS: TODO: type description here.
        SPEEDCOURIERS_GR: TODO: type description here.
        FORRUN: TODO: type description here.
        PICKUP: TODO: type description here.
        ECMS: TODO: type description here.
        INTELIPOST: TODO: type description here.
        FLASHEXPRESS: TODO: type description here.
        CN_STO: TODO: type description here.
        SEKO_SFTP: TODO: type description here.
        HOME_DELIVERY_SOLUTIONS: TODO: type description here.
        DPD_HGRY: TODO: type description here.
        KERRYTTC_VN: TODO: type description here.
        JOYING_BOX: TODO: type description here.
        TOTAL_EXPRESS: TODO: type description here.
        ZJS_EXPRESS: TODO: type description here.
        STARKEN: TODO: type description here.
        DEMANDSHIP: TODO: type description here.
        CN_DPEX: TODO: type description here.
        AUPOST_CN: TODO: type description here.
        LOGISTERS: TODO: type description here.
        GOGLOBALPOST: TODO: type description here.
        GLS_CZ: TODO: type description here.
        PAACK_WEBHOOK: TODO: type description here.
        GRAB_WEBHOOK: TODO: type description here.
        PARCELPOINT: TODO: type description here.
        ICUMULUS: TODO: type description here.
        DAIGLOBALTRACK: TODO: type description here.
        GLOBAL_IPARCEL: TODO: type description here.
        YURTICI_KARGO: TODO: type description here.
        CN_PAYPAL_PACKAGE: TODO: type description here.
        PARCEL_2_POST: TODO: type description here.
        GLS_IT: TODO: type description here.
        PIL_LOGISTICS: TODO: type description here.
        HEPPNER: TODO: type description here.
        GENERAL_OVERNIGHT: TODO: type description here.
        HAPPY2POINT: TODO: type description here.
        CHITCHATS: TODO: type description here.
        SMOOTH: TODO: type description here.
        CLE_LOGISTICS: TODO: type description here.
        FIEGE: TODO: type description here.
        MX_CARGO: TODO: type description here.
        ZIINGFINALMILE: TODO: type description here.
        DAYTON_FREIGHT: TODO: type description here.
        TCS: TODO: type description here.
        AEX: TODO: type description here.
        HERMES_DE: TODO: type description here.
        ROUTIFIC_WEBHOOK: TODO: type description here.
        GLOBAVEND: TODO: type description here.
        CJ_LOGISTICS: TODO: type description here.
        PALLET_NETWORK: TODO: type description here.
        RAF_PH: TODO: type description here.
        UK_XDP: TODO: type description here.
        PAPER_EXPRESS: TODO: type description here.
        LA_POSTE_SUIVI: TODO: type description here.
        PAQUETEXPRESS: TODO: type description here.
        LIEFERY: TODO: type description here.
        STRECK_TRANSPORT: TODO: type description here.
        PONY_EXPRESS: TODO: type description here.
        ALWAYS_EXPRESS: TODO: type description here.
        GBS_BROKER: TODO: type description here.
        CITYLINK_MY: TODO: type description here.
        ALLJOY: TODO: type description here.
        YODEL: TODO: type description here.
        YODEL_DIR: TODO: type description here.
        STONE3PL: TODO: type description here.
        PARCELPAL_WEBHOOK: TODO: type description here.
        DHL_ECOMERCE_ASA: TODO: type description here.
        SIMPLYPOST: TODO: type description here.
        KY_EXPRESS: TODO: type description here.
        SHENZHEN: TODO: type description here.
        US_LASERSHIP: TODO: type description here.
        UC_EXPRE: TODO: type description here.
        DIDADI: TODO: type description here.
        CJ_KR: TODO: type description here.
        DBSCHENKER_B2B: TODO: type description here.
        MXE: TODO: type description here.
        CAE_DELIVERS: TODO: type description here.
        PFCEXPRESS: TODO: type description here.
        WHISTL: TODO: type description here.
        WEPOST: TODO: type description here.
        DHL_PARCEL_ES: TODO: type description here.
        DDEXPRESS: TODO: type description here.
        ARAMEX_AU: TODO: type description here.
        BNEED: TODO: type description here.
        HK_TGX: TODO: type description here.
        LATVIJAS_PASTS: TODO: type description here.
        VIAEUROPE: TODO: type description here.
        CORREO_UY: TODO: type description here.
        CHRONOPOST_FR: TODO: type description here.
        J_NET: TODO: type description here.
        _6LS: TODO: type description here.
        BLR_BELPOST: TODO: type description here.
        BIRDSYSTEM: TODO: type description here.
        DOBROPOST: TODO: type description here.
        WAHANA_ID: TODO: type description here.
        WEASHIP: TODO: type description here.
        SONICTL: TODO: type description here.
        KWT: TODO: type description here.
        AFLLOG_FTP: TODO: type description here.
        SKYNET_WORLDWIDE: TODO: type description here.
        NOVA_POSHTA: TODO: type description here.
        SEINO: TODO: type description here.
        SZENDEX: TODO: type description here.
        BPOST_INT: TODO: type description here.
        DBSCHENKER_SV: TODO: type description here.
        AO_DEUTSCHLAND: TODO: type description here.
        EU_FLEET_SOLUTIONS: TODO: type description here.
        PCFCORP: TODO: type description here.
        LINKBRIDGE: TODO: type description here.
        PRIMAMULTICIPTA: TODO: type description here.
        COUREX: TODO: type description here.
        ZAJIL_EXPRESS: TODO: type description here.
        COLLECTCO: TODO: type description here.
        JTEXPRESS: TODO: type description here.
        FEDEX_UK: TODO: type description here.
        USHIP: TODO: type description here.
        PIXSELL: TODO: type description here.
        SHIPTOR: TODO: type description here.
        CDEK: TODO: type description here.
        VNM_VIETTELPOST: TODO: type description here.
        CJ_CENTURY: TODO: type description here.
        GSO: TODO: type description here.
        VIWO: TODO: type description here.
        SKYBOX: TODO: type description here.
        KERRYTJ: TODO: type description here.
        NTLOGISTICS_VN: TODO: type description here.
        SDH_SCM: TODO: type description here.
        ZINC: TODO: type description here.
        DPE_SOUTH_AFRC: TODO: type description here.
        CESKA_CZ: TODO: type description here.
        ACS_GR: TODO: type description here.
        DEALERSEND: TODO: type description here.
        JOCOM: TODO: type description here.
        CSE: TODO: type description here.
        TFORCE_FINALMILE: TODO: type description here.
        SHIP_GATE: TODO: type description here.
        SHIPTER: TODO: type description here.
        NATIONAL_SAMEDAY: TODO: type description here.
        YUNEXPRESS: TODO: type description here.
        CAINIAO: TODO: type description here.
        DMS_MATRIX: TODO: type description here.
        DIRECTLOG: TODO: type description here.
        ASENDIA_US: TODO: type description here.
        _3JMSLOGISTICS: TODO: type description here.
        LICCARDI_EXPRESS: TODO: type description here.
        SKY_POSTAL: TODO: type description here.
        CNWANGTONG: TODO: type description here.
        POSTNORD_LOGISTICS_DK: TODO: type description here.
        LOGISTIKA: TODO: type description here.
        CELERITAS: TODO: type description here.
        PRESSIODE: TODO: type description here.
        SHREE_MARUTI: TODO: type description here.
        LOGISTICSWORLDWIDE_HK: TODO: type description here.
        EFEX: TODO: type description here.
        LOTTE: TODO: type description here.
        LONESTAR: TODO: type description here.
        APRISAEXPRESS: TODO: type description here.
        BEL_RS: TODO: type description here.
        OSM_WORLDWIDE: TODO: type description here.
        WESTGATE_GL: TODO: type description here.
        FASTRACK: TODO: type description here.
        DTD_EXPR: TODO: type description here.
        ALFATREX: TODO: type description here.
        PROMEDDELIVERY: TODO: type description here.
        THABIT_LOGISTICS: TODO: type description here.
        HCT_LOGISTICS: TODO: type description here.
        CARRY_FLAP: TODO: type description here.
        US_OLD_DOMINION: TODO: type description here.
        ANICAM_BOX: TODO: type description here.
        WANBEXPRESS: TODO: type description here.
        AN_POST: TODO: type description here.
        DPD_LOCAL: TODO: type description here.
        STALLIONEXPRESS: TODO: type description here.
        RAIDEREX: TODO: type description here.
        SHOPFANS: TODO: type description here.
        KYUNGDONG_PARCEL: TODO: type description here.
        CHAMPION_LOGISTICS: TODO: type description here.
        PICKUPP_SGP: TODO: type description here.
        MORNING_EXPRESS: TODO: type description here.
        NACEX: TODO: type description here.
        THENILE_WEBHOOK: TODO: type description here.
        HOLISOL: TODO: type description here.
        LBCEXPRESS_FTP: TODO: type description here.
        KURASI: TODO: type description here.
        USF_REDDAWAY: TODO: type description here.
        APG: TODO: type description here.
        CN_BOXC: TODO: type description here.
        ECOSCOOTING: TODO: type description here.
        MAINWAY: TODO: type description here.
        PAPERFLY: TODO: type description here.
        HOUNDEXPRESS: TODO: type description here.
        BOX_BERRY: TODO: type description here.
        EP_BOX: TODO: type description here.
        PLUS_LOG_UK: TODO: type description here.
        FULFILLA: TODO: type description here.
        ASE: TODO: type description here.
        MAIL_PLUS: TODO: type description here.
        XPO_LOGISTICS: TODO: type description here.
        WNDIRECT: TODO: type description here.
        CLOUDWISH_ASIA: TODO: type description here.
        ZELERIS: TODO: type description here.
        GIO_EXPRESS: TODO: type description here.
        OCS_WORLDWIDE: TODO: type description here.
        ARK_LOGISTICS: TODO: type description here.
        AQUILINE: TODO: type description here.
        PILOT_FREIGHT: TODO: type description here.
        QWINTRY: TODO: type description here.
        DANSKE_FRAGT: TODO: type description here.
        CARRIERS: TODO: type description here.
        AIR_CANADA_GLOBAL: TODO: type description here.
        PRESIDENT_TRANS: TODO: type description here.
        STEPFORWARDFS: TODO: type description here.
        SKYNET_UK: TODO: type description here.
        PITTOHIO: TODO: type description here.
        CORREOS_EXPRESS: TODO: type description here.
        RL_US: TODO: type description here.
        MARA_XPRESS: TODO: type description here.
        DESTINY: TODO: type description here.
        UK_YODEL: TODO: type description here.
        COMET_TECH: TODO: type description here.
        DHL_PARCEL_RU: TODO: type description here.
        TNT_REFR: TODO: type description here.
        SHREE_ANJANI_COURIER: TODO: type description here.
        MIKROPAKKET_BE: TODO: type description here.
        ETS_EXPRESS: TODO: type description here.
        COLIS_PRIVE: TODO: type description here.
        CN_YUNDA: TODO: type description here.
        AAA_COOPER: TODO: type description here.
        ROCKET_PARCEL: TODO: type description here.
        _360LION: TODO: type description here.
        PANDU: TODO: type description here.
        PROFESSIONAL_COURIERS: TODO: type description here.
        FLYTEXPRESS: TODO: type description here.
        LOGISTICSWORLDWIDE_MY: TODO: type description here.
        CORREOS_DE_ESPANA: TODO: type description here.
        IMX: TODO: type description here.
        FOUR_PX_EXPRESS: TODO: type description here.
        XPRESSBEES: TODO: type description here.
        PICKUPP_VNM: TODO: type description here.
        STARTRACK_EXPRESS1: TODO: type description here.
        FR_COLISSIMO: TODO: type description here.
        NACEX_SPAIN_REFERENCE: TODO: type description here.
        DHL_SUPPLY_CHAIN_AU: TODO: type description here.
        ESHIPPING: TODO: type description here.
        SHREETIRUPATI: TODO: type description here.
        HX_EXPRESS: TODO: type description here.
        INDOPAKET: TODO: type description here.
        CN_17POST: TODO: type description here.
        K1_EXPRESS: TODO: type description here.
        CJ_GLS: TODO: type description here.
        MYS_GDEX: TODO: type description here.
        NATIONEX: TODO: type description here.
        ANJUN: TODO: type description here.
        FARGOOD: TODO: type description here.
        SMG_EXPRESS: TODO: type description here.
        RZYEXPRESS: TODO: type description here.
        SEFL: TODO: type description here.
        TNT_CLICK_IT: TODO: type description here.
        HDB: TODO: type description here.
        HIPSHIPPER: TODO: type description here.
        RPXLOGISTICS: TODO: type description here.
        KUEHNE: TODO: type description here.
        IT_NEXIVE: TODO: type description here.
        PTS: TODO: type description here.
        SWISS_POST_FTP: TODO: type description here.
        FASTRK_SERV: TODO: type description here.
        _4_72: TODO: type description here.
        US_YRC: TODO: type description here.
        POSTNL_INTL_3S: TODO: type description here.
        ELIAN_POST: TODO: type description here.
        CUBYN: TODO: type description here.
        SAU_SAUDI_POST: TODO: type description here.
        ABXEXPRESS_MY: TODO: type description here.
        HUAHAN_EXPRESS: TODO: type description here.
        IND_JAYONEXPRESS: TODO: type description here.
        ZES_EXPRESS: TODO: type description here.
        ZEPTO_EXPRESS: TODO: type description here.
        SKYNET_ZA: TODO: type description here.
        ZEEK_2_DOOR: TODO: type description here.
        BLINKLASTMILE: TODO: type description here.
        POSTA_UKR: TODO: type description here.
        CHROBINSON: TODO: type description here.
        CN_POST56: TODO: type description here.
        COURANT_PLUS: TODO: type description here.
        SCUDEX_EXPRESS: TODO: type description here.
        SHIPENTEGRA: TODO: type description here.
        B_TWO_C_EUROPE: TODO: type description here.
        COPE: TODO: type description here.
        IND_GATI: TODO: type description here.
        CN_WISHPOST: TODO: type description here.
        NACEX_ES: TODO: type description here.
        TAQBIN_HK: TODO: type description here.
        GLOBALTRANZ: TODO: type description here.
        HKD: TODO: type description here.
        BJSHOMEDELIVERY: TODO: type description here.
        OMNIVA: TODO: type description here.
        SUTTON: TODO: type description here.
        PANTHER_REFERENCE: TODO: type description here.
        SFCSERVICE: TODO: type description here.
        LTL: TODO: type description here.
        PARKNPARCEL: TODO: type description here.
        SPRING_GDS: TODO: type description here.
        ECEXPRESS: TODO: type description here.
        INTERPARCEL_AU: TODO: type description here.
        AGILITY: TODO: type description here.
        XL_EXPRESS: TODO: type description here.
        ADERONLINE: TODO: type description here.
        DIRECTCOURIERS: TODO: type description here.
        PLANZER: TODO: type description here.
        SENDING: TODO: type description here.
        NINJAVAN_WB: TODO: type description here.
        NATIONWIDE_MY: TODO: type description here.
        SENDIT: TODO: type description here.
        GB_ARROW: TODO: type description here.
        IND_GOJAVAS: TODO: type description here.
        KPOST: TODO: type description here.
        DHL_FREIGHT: TODO: type description here.
        BLUECARE: TODO: type description here.
        JINDOUYUN: TODO: type description here.
        TRACKON: TODO: type description here.
        GB_TUFFNELLS: TODO: type description here.
        TRUMPCARD: TODO: type description here.
        ETOTAL: TODO: type description here.
        SFPLUS_WEBHOOK: TODO: type description here.
        SEKOLOGISTICS: TODO: type description here.
        HERMES_2MANN_HANDLING: TODO: type description here.
        DPD_LOCAL_REF: TODO: type description here.
        UDS: TODO: type description here.
        ZA_SPECIALISED_FREIGHT: TODO: type description here.
        THA_KERRY: TODO: type description here.
        PRT_INT_SEUR: TODO: type description here.
        BRA_CORREIOS: TODO: type description here.
        NZ_NZ_POST: TODO: type description here.
        CN_EQUICK: TODO: type description here.
        MYS_EMS: TODO: type description here.
        GB_NORSK: TODO: type description here.
        ESP_MRW: TODO: type description here.
        ESP_PACKLINK: TODO: type description here.
        KANGAROO_MY: TODO: type description here.
        RPX: TODO: type description here.
        XDP_UK_REFERENCE: TODO: type description here.
        NINJAVAN_MY: TODO: type description here.
        ADICIONAL: TODO: type description here.
        NINJAVAN_ID: TODO: type description here.
        ROADBULL: TODO: type description here.
        YAKIT: TODO: type description here.
        MAILAMERICAS: TODO: type description here.
        MIKROPAKKET: TODO: type description here.
        DYNALOGIC: TODO: type description here.
        DHL_ES: TODO: type description here.
        DHL_PARCEL_NL: TODO: type description here.
        DHL_GLOBAL_MAIL_ASIA: TODO: type description here.
        DAWN_WING: TODO: type description here.
        GENIKI_GR: TODO: type description here.
        HERMESWORLD_UK: TODO: type description here.
        ALPHAFAST: TODO: type description here.
        BUYLOGIC: TODO: type description here.
        EKART: TODO: type description here.
        MEX_SENDA: TODO: type description here.
        SFC_LOGISTICS: TODO: type description here.
        POST_SERBIA: TODO: type description here.
        IND_DELHIVERY: TODO: type description here.
        DE_DPD_DELISTRACK: TODO: type description here.
        RPD2MAN: TODO: type description here.
        CN_SF_EXPRESS: TODO: type description here.
        YANWEN: TODO: type description here.
        MYS_SKYNET: TODO: type description here.
        CORREOS_DE_MEXICO: TODO: type description here.
        CBL_LOGISTICA: TODO: type description here.
        MEX_ESTAFETA: TODO: type description here.
        AU_AUSTRIAN_POST: TODO: type description here.
        RINCOS: TODO: type description here.
        NLD_DHL: TODO: type description here.
        RUSSIAN_POST: TODO: type description here.
        COURIERS_PLEASE: TODO: type description here.
        POSTNORD_LOGISTICS: TODO: type description here.
        FEDEX: TODO: type description here.
        DPE_EXPRESS: TODO: type description here.
        DPD: TODO: type description here.
        ADSONE: TODO: type description here.
        IDN_JNE: TODO: type description here.
        THECOURIERGUY: TODO: type description here.
        CNEXPS: TODO: type description here.
        PRT_CHRONOPOST: TODO: type description here.
        LANDMARK_GLOBAL: TODO: type description here.
        IT_DHL_ECOMMERCE: TODO: type description here.
        ESP_NACEX: TODO: type description here.
        PRT_CTT: TODO: type description here.
        BE_KIALA: TODO: type description here.
        ASENDIA_UK: TODO: type description here.
        GLOBAL_TNT: TODO: type description here.
        POSTUR_IS: TODO: type description here.
        EPARCEL_KR: TODO: type description here.
        INPOST_PACZKOMATY: TODO: type description here.
        IT_POSTE_ITALIA: TODO: type description here.
        BE_BPOST: TODO: type description here.
        PL_POCZTA_POLSKA: TODO: type description here.
        MYS_MYS_POST: TODO: type description here.
        SG_SG_POST: TODO: type description here.
        THA_THAILAND_POST: TODO: type description here.
        LEXSHIP: TODO: type description here.
        FASTWAY_NZ: TODO: type description here.
        DHL_AU: TODO: type description here.
        COSTMETICSNOW: TODO: type description here.
        PFLOGISTICS: TODO: type description here.
        LOOMIS_EXPRESS: TODO: type description here.
        GLS_ITALY: TODO: type description here.
        LINE: TODO: type description here.
        GEL_EXPRESS: TODO: type description here.
        HUODULL: TODO: type description here.
        NINJAVAN_SG: TODO: type description here.
        JANIO: TODO: type description here.
        AO_COURIER: TODO: type description here.
        BRT_IT_SENDER_REF: TODO: type description here.
        SAILPOST: TODO: type description here.
        LALAMOVE: TODO: type description here.
        NEWZEALAND_COURIERS: TODO: type description here.
        ETOMARS: TODO: type description here.
        VIRTRANSPORT: TODO: type description here.
        WIZMO: TODO: type description here.
        PALLETWAYS: TODO: type description here.
        I_DIKA: TODO: type description here.
        CFL_LOGISTICS: TODO: type description here.
        GEMWORLDWIDE: TODO: type description here.
        GLOBAL_EXPRESS: TODO: type description here.
        LOGISTYX_TRANSGROUP: TODO: type description here.
        WESTBANK_COURIER: TODO: type description here.
        ARCO_SPEDIZIONI: TODO: type description here.
        YDH_EXPRESS: TODO: type description here.
        PARCELINKLOGISTICS: TODO: type description here.
        CNDEXPRESS: TODO: type description here.
        NOX_NIGHT_TIME_EXPRESS: TODO: type description here.
        AERONET: TODO: type description here.
        LTIANEXP: TODO: type description here.
        INTEGRA2_FTP: TODO: type description here.
        PARCELONE: TODO: type description here.
        NOX_NACHTEXPRESS: TODO: type description here.
        CN_CHINA_POST_EMS: TODO: type description here.
        CHUKOU1: TODO: type description here.
        GLS_SLOV: TODO: type description here.
        ORANGE_DS: TODO: type description here.
        JOOM_LOGIS: TODO: type description here.
        AUS_STARTRACK: TODO: type description here.
        DHL: TODO: type description here.
        GB_APC: TODO: type description here.
        BONDSCOURIERS: TODO: type description here.
        JPN_JAPAN_POST: TODO: type description here.
        USPS: TODO: type description here.
        WINIT: TODO: type description here.
        ARG_OCA: TODO: type description here.
        TW_TAIWAN_POST: TODO: type description here.
        DMM_NETWORK: TODO: type description here.
        TNT: TODO: type description here.
        BH_POSTA: TODO: type description here.
        SWE_POSTNORD: TODO: type description here.
        CA_CANADA_POST: TODO: type description here.
        WISELOADS: TODO: type description here.
        ASENDIA_HK: TODO: type description here.
        NLD_GLS: TODO: type description here.
        MEX_REDPACK: TODO: type description here.
        JET_SHIP: TODO: type description here.
        DE_DHL_EXPRESS: TODO: type description here.
        NINJAVAN_THAI: TODO: type description here.
        RABEN_GROUP: TODO: type description here.
        ESP_ASM: TODO: type description here.
        HRV_HRVATSKA: TODO: type description here.
        GLOBAL_ESTES: TODO: type description here.
        LTU_LIETUVOS: TODO: type description here.
        BEL_DHL: TODO: type description here.
        AU_AU_POST: TODO: type description here.
        SPEEDEXCOURIER: TODO: type description here.
        FR_COLIS: TODO: type description here.
        ARAMEX: TODO: type description here.
        DPEX: TODO: type description here.
        MYS_AIRPAK: TODO: type description here.
        CUCKOOEXPRESS: TODO: type description here.
        DPD_POLAND: TODO: type description here.
        NLD_POSTNL: TODO: type description here.
        NIM_EXPRESS: TODO: type description here.
        QUANTIUM: TODO: type description here.
        SENDLE: TODO: type description here.
        ESP_REDUR: TODO: type description here.
        MATKAHUOLTO: TODO: type description here.
        CPACKET: TODO: type description here.
        POSTI: TODO: type description here.
        HUNTER_EXPRESS: TODO: type description here.
        CHOIR_EXP: TODO: type description here.
        LEGION_EXPRESS: TODO: type description here.
        AUSTRIAN_POST_EXPRESS: TODO: type description here.
        GRUPO: TODO: type description here.
        POSTA_RO: TODO: type description here.
        INTERPARCEL_UK: TODO: type description here.
        GLOBAL_ABF: TODO: type description here.
        POSTEN_NORGE: TODO: type description here.
        XPERT_DELIVERY: TODO: type description here.
        DHL_REFR: TODO: type description here.
        DHL_HK: TODO: type description here.
        SKYNET_UAE: TODO: type description here.
        GOJEK: TODO: type description here.
        YODEL_INTNL: TODO: type description here.
        JANCO: TODO: type description here.
        YTO: TODO: type description here.
        WISE_EXPRESS: TODO: type description here.
        JTEXPRESS_VN: TODO: type description here.
        FEDEX_INTL_MLSERV: TODO: type description here.
        VAMOX: TODO: type description here.
        AMS_GRP: TODO: type description here.
        DHL_JP: TODO: type description here.
        HRPARCEL: TODO: type description here.
        GESWL: TODO: type description here.
        BLUESTAR: TODO: type description here.
        CDEK_TR: TODO: type description here.
        DESCARTES: TODO: type description here.
        DELTEC_UK: TODO: type description here.
        DTDC_EXPRESS: TODO: type description here.
        TOURLINE: TODO: type description here.
        BH_WORLDWIDE: TODO: type description here.
        OCS: TODO: type description here.
        YINGNUO_LOGISTICS: TODO: type description here.
        UPS: TODO: type description here.
        TOLL: TODO: type description here.
        PRT_SEUR: TODO: type description here.
        DTDC_AU: TODO: type description here.
        THA_DYNAMIC_LOGISTICS: TODO: type description here.
        UBI_LOGISTICS: TODO: type description here.
        FEDEX_CROSSBORDER: TODO: type description here.
        A1POST: TODO: type description here.
        TAZMANIAN_FREIGHT: TODO: type description here.
        CJ_INT_MY: TODO: type description here.
        SAIA_FREIGHT: TODO: type description here.
        SG_QXPRESS: TODO: type description here.
        NHANS_SOLUTIONS: TODO: type description here.
        DPD_FR: TODO: type description here.
        COORDINADORA: TODO: type description here.
        ANDREANI: TODO: type description here.
        DOORA: TODO: type description here.
        INTERPARCEL_NZ: TODO: type description here.
        PHL_JAMEXPRESS: TODO: type description here.
        BEL_BELGIUM_POST: TODO: type description here.
        US_APC: TODO: type description here.
        IDN_POS: TODO: type description here.
        FR_MONDIAL: TODO: type description here.
        DE_DHL: TODO: type description here.
        HK_RPX: TODO: type description here.
        DHL_PIECEID: TODO: type description here.
        VNPOST_EMS: TODO: type description here.
        RRDONNELLEY: TODO: type description here.
        DPD_DE: TODO: type description here.
        DELCART_IN: TODO: type description here.
        IMEXGLOBALSOLUTIONS: TODO: type description here.
        ACOMMERCE: TODO: type description here.
        EURODIS: TODO: type description here.
        CANPAR: TODO: type description here.
        GLS: TODO: type description here.
        IND_ECOM: TODO: type description here.
        ESP_ENVIALIA: TODO: type description here.
        DHL_UK: TODO: type description here.
        SMSA_EXPRESS: TODO: type description here.
        TNT_FR: TODO: type description here.
        DEX_I: TODO: type description here.
        BUDBEE_WEBHOOK: TODO: type description here.
        COPA_COURIER: TODO: type description here.
        VNM_VIETNAM_POST: TODO: type description here.
        DPD_HK: TODO: type description here.
        TOLL_NZ: TODO: type description here.
        ECHO: TODO: type description here.
        FEDEX_FR: TODO: type description here.
        BORDEREXPRESS: TODO: type description here.
        MAILPLUS_JPN: TODO: type description here.
        TNT_UK_REFR: TODO: type description here.
        KEC: TODO: type description here.
        DPD_RO: TODO: type description here.
        TNT_JP: TODO: type description here.
        TH_CJ: TODO: type description here.
        EC_CN: TODO: type description here.
        FASTWAY_UK: TODO: type description here.
        FASTWAY_US: TODO: type description here.
        GLS_DE: TODO: type description here.
        GLS_ES: TODO: type description here.
        GLS_FR: TODO: type description here.
        MONDIAL_BE: TODO: type description here.
        SGT_IT: TODO: type description here.
        TNT_CN: TODO: type description here.
        TNT_DE: TODO: type description here.
        TNT_ES: TODO: type description here.
        TNT_PL: TODO: type description here.
        PARCELFORCE: TODO: type description here.
        SWISS_POST: TODO: type description here.
        TOLL_IPEC: TODO: type description here.
        AIR_21: TODO: type description here.
        AIRSPEED: TODO: type description here.
        BERT: TODO: type description here.
        BLUEDART: TODO: type description here.
        COLLECTPLUS: TODO: type description here.
        COURIERPLUS: TODO: type description here.
        COURIER_POST: TODO: type description here.
        DHL_GLOBAL_MAIL: TODO: type description here.
        DPD_UK: TODO: type description here.
        DELTEC_DE: TODO: type description here.
        DEUTSCHE_DE: TODO: type description here.
        DOTZOT: TODO: type description here.
        ELTA_GR: TODO: type description here.
        EMS_CN: TODO: type description here.
        ECARGO: TODO: type description here.
        ENSENDA: TODO: type description here.
        FERCAM_IT: TODO: type description here.
        FASTWAY_ZA: TODO: type description here.
        FASTWAY_AU: TODO: type description here.
        FIRST_LOGISITCS: TODO: type description here.
        GEODIS: TODO: type description here.
        GLOBEGISTICS: TODO: type description here.
        GREYHOUND: TODO: type description here.
        JETSHIP_MY: TODO: type description here.
        LION_PARCEL: TODO: type description here.
        AEROFLASH: TODO: type description here.
        ONTRAC: TODO: type description here.
        SAGAWA: TODO: type description here.
        SIODEMKA: TODO: type description here.
        STARTRACK: TODO: type description here.
        TNT_AU: TODO: type description here.
        TNT_IT: TODO: type description here.
        TRANSMISSION: TODO: type description here.
        YAMATO: TODO: type description here.
        DHL_IT: TODO: type description here.
        DHL_AT: TODO: type description here.
        LOGISTICSWORLDWIDE_KR: TODO: type description here.
        GLS_SPAIN: TODO: type description here.
        AMAZON_UK_API: TODO: type description here.
        DPD_FR_REFERENCE: TODO: type description here.
        DHLPARCEL_UK: TODO: type description here.
        MEGASAVE: TODO: type description here.
        QUALITYPOST: TODO: type description here.
        IDS_LOGISTICS: TODO: type description here.
        JOYINGBOX1: TODO: type description here.
        PANTHER_ORDER_NUMBER: TODO: type description here.
        WATKINS_SHEPARD: TODO: type description here.
        FASTTRACK: TODO: type description here.
        UP_EXPRESS: TODO: type description here.
        ELOGISTICA: TODO: type description here.
        ECOURIER: TODO: type description here.
        CJ_PHILIPPINES: TODO: type description here.
        SPEEDEX: TODO: type description here.
        ORANGECONNEX: TODO: type description here.
        TECOR: TODO: type description here.
        SAEE: TODO: type description here.
        GLS_ITALY_FTP: TODO: type description here.
        DELIVERE: TODO: type description here.
        YYCOM: TODO: type description here.
        ADICIONAL_PT: TODO: type description here.
        DKSH: TODO: type description here.
        NIPPON_EXPRESS_FTP: TODO: type description here.
        GOLS: TODO: type description here.
        FUJEXP: TODO: type description here.
        QTRACK: TODO: type description here.
        OMLOGISTICS_API: TODO: type description here.
        GDPHARM: TODO: type description here.
        MISUMI_CN: TODO: type description here.
        AIR_CANADA: TODO: type description here.
        CITY56_WEBHOOK: TODO: type description here.
        SAGAWA_API: TODO: type description here.
        KEDAEX: TODO: type description here.
        PGEON_API: TODO: type description here.
        WEWORLDEXPRESS: TODO: type description here.
        JT_LOGISTICS: TODO: type description here.
        TRUSK: TODO: type description here.
        VIAXPRESS: TODO: type description here.
        DHL_SUPPLYCHAIN_ID: TODO: type description here.
        ZUELLIGPHARMA_SFTP: TODO: type description here.
        MEEST: TODO: type description here.
        TOLL_PRIORITY: TODO: type description here.
        MOTHERSHIP_API: TODO: type description here.
        CAPITAL: TODO: type description here.
        EUROPAKET_API: TODO: type description here.
        HFD: TODO: type description here.
        TOURLINE_REFERENCE: TODO: type description here.
        GIO_ECOURIER: TODO: type description here.
        CN_LOGISTICS: TODO: type description here.
        PANDION: TODO: type description here.
        BPOST_API: TODO: type description here.
        PASSPORTSHIPPING: TODO: type description here.
        PAKAJO: TODO: type description here.
        DACHSER: TODO: type description here.
        YUSEN_SFTP: TODO: type description here.
        SHYPLITE: TODO: type description here.
        XYY: TODO: type description here.
        MWD: TODO: type description here.
        FAXECARGO: TODO: type description here.
        MAZET: TODO: type description here.
        FIRST_LOGISTICS_API: TODO: type description here.
        SPRINT_PACK: TODO: type description here.
        HERMES_DE_FTP: TODO: type description here.
        CONCISE: TODO: type description here.
        KERRY_EXPRESS_TW_API: TODO: type description here.
        EWE: TODO: type description here.
        FASTDESPATCH: TODO: type description here.
        ABCUSTOM_SFTP: TODO: type description here.
        CHAZKI: TODO: type description here.
        SHIPPIE: TODO: type description here.
        GEODIS_API: TODO: type description here.
        NAQEL_EXPRESS: TODO: type description here.
        PAPA_WEBHOOK: TODO: type description here.
        FORWARDAIR: TODO: type description here.
        DIALOGO_LOGISTICA_API: TODO: type description here.
        LALAMOVE_API: TODO: type description here.
        TOMYDOOR: TODO: type description here.
        KRONOS_WEBHOOK: TODO: type description here.
        JTCARGO: TODO: type description here.
        T_CAT: TODO: type description here.
        CONCISE_WEBHOOK: TODO: type description here.
        TELEPORT_WEBHOOK: TODO: type description here.
        CUSTOMCO_API: TODO: type description here.
        SPX_TH: TODO: type description here.
        BOLLORE_LOGISTICS: TODO: type description here.
        CLICKLINK_SFTP: TODO: type description here.
        M3LOGISTICS: TODO: type description here.
        VNPOST_API: TODO: type description here.
        AXLEHIRE_FTP: TODO: type description here.
        SHADOWFAX: TODO: type description here.
        MYHERMES_UK_API: TODO: type description here.
        DAIICHI: TODO: type description here.
        MENSAJEROSURBANOS_API: TODO: type description here.
        POLARSPEED: TODO: type description here.
        IDEXPRESS_ID: TODO: type description here.
        PAYO: TODO: type description here.
        WHISTL_SFTP: TODO: type description here.
        INTEX_DE: TODO: type description here.
        TRANS2U: TODO: type description here.
        PRODUCTCAREGROUP_SFTP: TODO: type description here.
        BIGSMART: TODO: type description here.
        EXPEDITORS_API_REF: TODO: type description here.
        AITWORLDWIDE_API: TODO: type description here.
        WORLDCOURIER: TODO: type description here.
        QUIQUP: TODO: type description here.
        AGEDISS_SFTP: TODO: type description here.
        ANDREANI_API: TODO: type description here.
        CRLEXPRESS: TODO: type description here.
        SMARTCAT: TODO: type description here.
        CROSSFLIGHT: TODO: type description here.
        PROCARRIER: TODO: type description here.
        DHL_REFERENCE_API: TODO: type description here.
        SEINO_API: TODO: type description here.
        WSPEXPRESS: TODO: type description here.
        KRONOS: TODO: type description here.
        TOTAL_EXPRESS_API: TODO: type description here.
        PARCLL: TODO: type description here.
        XPEDIGO: TODO: type description here.
        STAR_TRACK_WEBHOOK: TODO: type description here.
        GPOST: TODO: type description here.
        UCS: TODO: type description here.
        DMFGROUP: TODO: type description here.
        COORDINADORA_API: TODO: type description here.
        MARKEN: TODO: type description here.
        NTL: TODO: type description here.
        REDJEPAKKETJE: TODO: type description here.
        ALLIED_EXPRESS_FTP: TODO: type description here.
        MONDIALRELAY_ES: TODO: type description here.
        NAEKO_FTP: TODO: type description here.
        MHI: TODO: type description here.
        SHIPPIFY: TODO: type description here.
        MALCA_AMIT_API: TODO: type description here.
        JTEXPRESS_SG_API: TODO: type description here.
        DACHSER_WEB: TODO: type description here.
        FLIGHTLG: TODO: type description here.
        CAGO: TODO: type description here.
        COM1EXPRESS: TODO: type description here.
        TONAMI_FTP: TODO: type description here.
        PACKFLEET: TODO: type description here.
        PUROLATOR_INTERNATIONAL: TODO: type description here.
        WINESHIPPING_WEBHOOK: TODO: type description here.
        DHL_ES_SFTP: TODO: type description here.
        PCHOME_API: TODO: type description here.
        CESKAPOSTA_API: TODO: type description here.
        GORUSH: TODO: type description here.
        HOMERUNNER: TODO: type description here.
        AMAZON_ORDER: TODO: type description here.
        EFWNOW_API: TODO: type description here.
        CBL_LOGISTICA_API: TODO: type description here.
        NIMBUSPOST: TODO: type description here.
        LOGWIN_LOGISTICS: TODO: type description here.
        NOWLOG_API: TODO: type description here.
        DPD_NL: TODO: type description here.
        GODEPENDABLE: TODO: type description here.
        ESDEX: TODO: type description here.
        LOGISYSTEMS_SFTP: TODO: type description here.
        EXPEDITORS: TODO: type description here.
        SNTGLOBAL_API: TODO: type description here.
        SHIPX: TODO: type description here.
        QINTL_API: TODO: type description here.
        PACKS: TODO: type description here.
        POSTNL_INTERNATIONAL: TODO: type description here.
        AMAZON_EMAIL_PUSH: TODO: type description here.
        DHL_API: TODO: type description here.
        SPX: TODO: type description here.
        AXLEHIRE: TODO: type description here.
        ICSCOURIER: TODO: type description here.
        DIALOGO_LOGISTICA: TODO: type description here.
        SHUNBANG_EXPRESS: TODO: type description here.
        TCS_API: TODO: type description here.
        SF_EXPRESS_CN: TODO: type description here.
        PACKETA: TODO: type description here.
        SIC_TELIWAY: TODO: type description here.
        MONDIALRELAY_FR: TODO: type description here.
        INTIME_FTP: TODO: type description here.
        JD_EXPRESS: TODO: type description here.
        FASTBOX: TODO: type description here.
        PATHEON: TODO: type description here.
        INDIA_POST: TODO: type description here.
        TIPSA_REF: TODO: type description here.
        ECOFREIGHT: TODO: type description here.
        VOX: TODO: type description here.
        DIRECTFREIGHT_AU_REF: TODO: type description here.
        BESTTRANSPORT_SFTP: TODO: type description here.
        AUSTRALIA_POST_API: TODO: type description here.
        FRAGILEPAK_SFTP: TODO: type description here.
        FLIPXP: TODO: type description here.
        VALUE_WEBHOOK: TODO: type description here.
        DAESHIN: TODO: type description here.
        SHERPA: TODO: type description here.
        MWD_API: TODO: type description here.
        SMARTKARGO: TODO: type description here.
        DNJ_EXPRESS: TODO: type description here.
        GOPEOPLE: TODO: type description here.
        MYSENDLE_API: TODO: type description here.
        ARAMEX_API: TODO: type description here.
        PIDGE: TODO: type description here.
        THAIPARCELS: TODO: type description here.
        PANTHER_REFERENCE_API: TODO: type description here.
        POSTAPLUS1: TODO: type description here.
        BUFFALO: TODO: type description here.
        U_ENVIOS: TODO: type description here.
        ELITE_CO: TODO: type description here.
        BARQEXP: TODO: type description here.
        ROCHE_INTERNAL_SFTP: TODO: type description here.
        DBSCHENKER_ICELAND: TODO: type description here.
        TNT_FR_REFERENCE: TODO: type description here.
        NEWGISTICSAPI: TODO: type description here.
        GLOVO: TODO: type description here.
        GWLOGIS_API: TODO: type description here.
        SPREETAIL_API: TODO: type description here.
        MOOVA: TODO: type description here.
        PLYCONGROUP: TODO: type description here.
        USPS_WEBHOOK: TODO: type description here.
        REIMAGINEDELIVERY: TODO: type description here.
        EDF_FTP: TODO: type description here.
        DAO365: TODO: type description here.
        BIOCAIR_FTP: TODO: type description here.
        RANSA_WEBHOOK: TODO: type description here.
        SHIPXPRES: TODO: type description here.
        COURANT_PLUS_API: TODO: type description here.
        SHIPA: TODO: type description here.
        HOMELOGISTICS: TODO: type description here.
        DX: TODO: type description here.
        POSTE_ITALIANE_PACCOCELERE: TODO: type description here.
        TOLL_WEBHOOK: TODO: type description here.
        LCTBR_API: TODO: type description here.
        DX_FREIGHT: TODO: type description here.
        DHL_SFTP: TODO: type description here.
        SHIPROCKET: TODO: type description here.
        UBER_WEBHOOK: TODO: type description here.
        STATOVERNIGHT: TODO: type description here.
        BURD: TODO: type description here.
        FASTSHIP: TODO: type description here.
        IBVENTURE_WEBHOOK: TODO: type description here.
        GATI_KWE_API: TODO: type description here.
        CRYOPDP_FTP: TODO: type description here.
        HUBBED: TODO: type description here.
        TIPSA_API: TODO: type description here.
        ARASKARGO: TODO: type description here.
        THIJS_NL: TODO: type description here.
        ATSHEALTHCARE_REFERENCE: TODO: type description here.
        ENUM_99MINUTOS: TODO: type description here.
        HELLENIC_POST: TODO: type description here.
        HSM_GLOBAL: TODO: type description here.
        MNX: TODO: type description here.
        NMTRANSFER: TODO: type description here.
        LOGYSTO: TODO: type description here.
        INDIA_POST_INT: TODO: type description here.
        AMAZON_FBA_SWISHIP_IN: TODO: type description here.
        SRT_TRANSPORT: TODO: type description here.
        BOMI: TODO: type description here.
        DELIVERR_SFTP: TODO: type description here.
        HSDEXPRESS: TODO: type description here.
        SIMPLETIRE_WEBHOOK: TODO: type description here.
        HUNTER_EXPRESS_SFTP: TODO: type description here.
        UPS_API: TODO: type description here.
        WOOYOUNG_LOGISTICS_SFTP: TODO: type description here.
        PHSE_API: TODO: type description here.
        WISH_EMAIL_PUSH: TODO: type description here.
        NORTHLINE: TODO: type description here.
        MEDAFRICA: TODO: type description here.
        DPD_AT_SFTP: TODO: type description here.
        ANTERAJA: TODO: type description here.
        DHL_GLOBAL_FORWARDING_API: TODO: type description here.
        LBCEXPRESS_API: TODO: type description here.
        SIMSGLOBAL: TODO: type description here.
        CDLDELIVERS: TODO: type description here.
        TYP: TODO: type description here.
        TESTING_COURIER_WEBHOOK: TODO: type description here.
        PANDAGO_API: TODO: type description here.
        ROYAL_MAIL_FTP: TODO: type description here.
        THUNDEREXPRESS: TODO: type description here.
        SECRETLAB_WEBHOOK: TODO: type description here.
        SETEL: TODO: type description here.
        JD_WORLDWIDE: TODO: type description here.
        DPD_RU_API: TODO: type description here.
        ARGENTS_WEBHOOK: TODO: type description here.
        POSTONE: TODO: type description here.
        TUSKLOGISTICS: TODO: type description here.
        RHENUS_UK_API: TODO: type description here.
        TAQBIN_SG_API: TODO: type description here.
        INNTRALOG_SFTP: TODO: type description here.
        DAYROSS: TODO: type description here.
        CORREOSEXPRESS_API: TODO: type description here.
        INTERNATIONAL_SEUR_API: TODO: type description here.
        YODEL_API: TODO: type description here.
        HEROEXPRESS: TODO: type description here.
        DHL_SUPPLYCHAIN_IN: TODO: type description here.
        URGENT_CARGUS: TODO: type description here.
        FRONTDOORCORP: TODO: type description here.
        JTEXPRESS_PH: TODO: type description here.
        PARCELSTARS_WEBHOOK: TODO: type description here.
        DPD_SK_SFTP: TODO: type description here.
        MOVIANTO: TODO: type description here.
        OZEPARTS_SHIPPING: TODO: type description here.
        KARGOMKOLAY: TODO: type description here.
        TRUNKRS: TODO: type description here.
        OMNIRPS_WEBHOOK: TODO: type description here.
        CHILEXPRESS: TODO: type description here.
        TESTING_COURIER: TODO: type description here.
        JNE_API: TODO: type description here.
        BJSHOMEDELIVERY_FTP: TODO: type description here.
        DEXPRESS_WEBHOOK: TODO: type description here.
        USPS_API: TODO: type description here.
        TRANSVIRTUAL: TODO: type description here.
        SOLISTICA_API: TODO: type description here.
        CHIENVENTURE_WEBHOOK: TODO: type description here.
        DPD_UK_SFTP: TODO: type description here.
        INPOST_UK: TODO: type description here.
        JAVIT: TODO: type description here.
        ZTO_DOMESTIC: TODO: type description here.
        DHL_GT_API: TODO: type description here.
        CEVA_TRACKING: TODO: type description here.
        KOMON_EXPRESS: TODO: type description here.
        EASTWESTCOURIER_FTP: TODO: type description here.
        DANNIAO: TODO: type description here.
        SPECTRAN: TODO: type description here.
        DELIVER_IT: TODO: type description here.
        RELAISCOLIS: TODO: type description here.
        GLS_SPAIN_API: TODO: type description here.
        POSTPLUS: TODO: type description here.
        AIRTERRA: TODO: type description here.
        GIO_ECOURIER_API: TODO: type description here.
        DPD_CH_SFTP: TODO: type description here.
        FEDEX_API: TODO: type description here.
        INTERSMARTTRANS: TODO: type description here.
        HERMES_UK_SFTP: TODO: type description here.
        EXELOT_FTP: TODO: type description here.
        DHL_PA_API: TODO: type description here.
        VIRTRANSPORT_SFTP: TODO: type description here.
        WORLDNET: TODO: type description here.
        INSTABOX_WEBHOOK: TODO: type description here.
        KNG: TODO: type description here.
        FLASHEXPRESS_WEBHOOK: TODO: type description here.
        MAGYAR_POSTA_API: TODO: type description here.
        WESHIP_API: TODO: type description here.
        OHI_WEBHOOK: TODO: type description here.
        MUDITA: TODO: type description here.
        BLUEDART_API: TODO: type description here.
        T_CAT_API: TODO: type description here.
        ADS: TODO: type description here.
        HERMES_IT: TODO: type description here.
        FITZMARK_API: TODO: type description here.
        POSTI_API: TODO: type description here.
        SMSA_EXPRESS_WEBHOOK: TODO: type description here.
        TAMERGROUP_WEBHOOK: TODO: type description here.
        LIVRAPIDE: TODO: type description here.
        NIPPON_EXPRESS: TODO: type description here.
        BETTERTRUCKS: TODO: type description here.
        FAN: TODO: type description here.
        PB_USPSFLATS_FTP: TODO: type description here.
        PARCELRIGHT: TODO: type description here.
        ITHINKLOGISTICS: TODO: type description here.
        KERRY_EXPRESS_TH_WEBHOOK: TODO: type description here.
        ECOUTIER: TODO: type description here.
        SHOWL: TODO: type description here.
        BRT_IT_API: TODO: type description here.
        RIXONHK_API: TODO: type description here.
        DBSCHENKER_API: TODO: type description here.
        ILYANGLOGIS: TODO: type description here.
        MAIL_BOX_ETC: TODO: type description here.
        WESHIP: TODO: type description here.
        DHL_GLOBAL_MAIL_API: TODO: type description here.
        ACTIVOS24_API: TODO: type description here.
        ATSHEALTHCARE: TODO: type description here.
        LUWJISTIK: TODO: type description here.
        GW_WORLD: TODO: type description here.
        FAIRSENDEN_API: TODO: type description here.
        SERVIP_WEBHOOK: TODO: type description here.
        SWISHIP: TODO: type description here.
        TANET: TODO: type description here.
        HOTSIN_CARGO: TODO: type description here.
        DIREX: TODO: type description here.
        HUANTONG: TODO: type description here.
        IMILE_API: TODO: type description here.
        BDMNET: TODO: type description here.
        AUEXPRESS: TODO: type description here.
        NYTLOGISTICS: TODO: type description here.
        DSV_REFERENCE: TODO: type description here.
        NOVOFARMA_WEBHOOK: TODO: type description here.
        AITWORLDWIDE_SFTP: TODO: type description here.
        SHOPOLIVE: TODO: type description here.
        FNF_ZA: TODO: type description here.
        DHL_ECOMMERCE_GC: TODO: type description here.
        FETCHR: TODO: type description here.
        STARLINKS_API: TODO: type description here.
        YYEXPRESS: TODO: type description here.
        SERVIENTREGA: TODO: type description here.
        HANJIN: TODO: type description here.
        SPANISH_SEUR_FTP: TODO: type description here.
        DX_B2B_CONNUM: TODO: type description here.
        HELTHJEM_API: TODO: type description here.
        INEXPOST: TODO: type description here.
        A2B_BA: TODO: type description here.
        RHENUS_GROUP: TODO: type description here.
        SBERLOGISTICS_RU: TODO: type description here.
        MALCA_AMIT: TODO: type description here.
        PPL: TODO: type description here.
        OSM_WORLDWIDE_SFTP: TODO: type description here.
        ACILOGISTIX: TODO: type description here.
        OPTIMACOURIER: TODO: type description here.
        NOVA_POSHTA_API: TODO: type description here.
        LOGGI: TODO: type description here.
        YIFAN: TODO: type description here.
        MYDYNALOGIC: TODO: type description here.
        MORNINGLOBAL: TODO: type description here.
        CONCISE_API: TODO: type description here.
        FXTRAN: TODO: type description here.
        DELIVERYOURPARCEL_ZA: TODO: type description here.
        UPARCEL: TODO: type description here.
        MOBI_BR: TODO: type description here.
        LOGINEXT_WEBHOOK: TODO: type description here.
        EMS: TODO: type description here.
        SPEEDY: TODO: type description here.

    """
    DPD_RU = 'DPD_RU'

    BG_BULGARIAN_POST = 'BG_BULGARIAN_POST'

    KR_KOREA_POST = 'KR_KOREA_POST'

    ZA_COURIERIT = 'ZA_COURIERIT'

    FR_EXAPAQ = 'FR_EXAPAQ'

    ARE_EMIRATES_POST = 'ARE_EMIRATES_POST'

    GAC = 'GAC'

    GEIS = 'GEIS'

    SF_EX = 'SF_EX'

    PAGO = 'PAGO'

    MYHERMES = 'MYHERMES'

    DIAMOND_EUROGISTICS = 'DIAMOND_EUROGISTICS'

    CORPORATECOURIERS_WEBHOOK = 'CORPORATECOURIERS_WEBHOOK'

    BOND = 'BOND'

    OMNIPARCEL = 'OMNIPARCEL'

    SK_POSTA = 'SK_POSTA'

    PUROLATOR = 'PUROLATOR'

    FETCHR_WEBHOOK = 'FETCHR_WEBHOOK'

    THEDELIVERYGROUP = 'THEDELIVERYGROUP'

    CELLO_SQUARE = 'CELLO_SQUARE'

    TARRIVE = 'TARRIVE'

    COLLIVERY = 'COLLIVERY'

    MAINFREIGHT = 'MAINFREIGHT'

    IND_FIRSTFLIGHT = 'IND_FIRSTFLIGHT'

    ACSWORLDWIDE = 'ACSWORLDWIDE'

    AMSTAN = 'AMSTAN'

    OKAYPARCEL = 'OKAYPARCEL'

    ENVIALIA_REFERENCE = 'ENVIALIA_REFERENCE'

    SEUR_ES = 'SEUR_ES'

    CONTINENTAL = 'CONTINENTAL'

    FDSEXPRESS = 'FDSEXPRESS'

    AMAZON_FBA_SWISHIP = 'AMAZON_FBA_SWISHIP'

    WYNGS = 'WYNGS'

    DHL_ACTIVE_TRACING = 'DHL_ACTIVE_TRACING'

    ZYLLEM = 'ZYLLEM'

    RUSTON = 'RUSTON'

    XPOST = 'XPOST'

    CORREOS_ES = 'CORREOS_ES'

    DHL_FR = 'DHL_FR'

    PAN_ASIA = 'PAN_ASIA'

    BRT_IT = 'BRT_IT'

    SRE_KOREA = 'SRE_KOREA'

    SPEEDEE = 'SPEEDEE'

    TNT_UK = 'TNT_UK'

    VENIPAK = 'VENIPAK'

    SHREENANDANCOURIER = 'SHREENANDANCOURIER'

    CROSHOT = 'CROSHOT'

    NIPOST_NG = 'NIPOST_NG'

    EPST_GLBL = 'EPST_GLBL'

    NEWGISTICS = 'NEWGISTICS'

    POST_SLOVENIA = 'POST_SLOVENIA'

    JERSEY_POST = 'JERSEY_POST'

    BOMBINOEXP = 'BOMBINOEXP'

    WMG = 'WMG'

    XQ_EXPRESS = 'XQ_EXPRESS'

    FURDECO = 'FURDECO'

    LHT_EXPRESS = 'LHT_EXPRESS'

    SOUTH_AFRICAN_POST_OFFICE = 'SOUTH_AFRICAN_POST_OFFICE'

    SPOTON = 'SPOTON'

    DIMERCO = 'DIMERCO'

    CYPRUS_POST_CYP = 'CYPRUS_POST_CYP'

    ABCUSTOM = 'ABCUSTOM'

    IND_DELIVREE = 'IND_DELIVREE'

    CN_BESTEXPRESS = 'CN_BESTEXPRESS'

    DX_SFTP = 'DX_SFTP'

    PICKUPP_MYS = 'PICKUPP_MYS'

    FMX = 'FMX'

    HELLMANN = 'HELLMANN'

    SHIP_IT_ASIA = 'SHIP_IT_ASIA'

    KERRY_ECOMMERCE = 'KERRY_ECOMMERCE'

    FRETERAPIDO = 'FRETERAPIDO'

    PITNEY_BOWES = 'PITNEY_BOWES'

    XPRESSEN_DK = 'XPRESSEN_DK'

    SEUR_SP_API = 'SEUR_SP_API'

    DELIVERYONTIME = 'DELIVERYONTIME'

    JINSUNG = 'JINSUNG'

    TRANS_KARGO = 'TRANS_KARGO'

    SWISHIP_DE = 'SWISHIP_DE'

    IVOY_WEBHOOK = 'IVOY_WEBHOOK'

    AIRMEE_WEBHOOK = 'AIRMEE_WEBHOOK'

    DHL_BENELUX = 'DHL_BENELUX'

    FIRSTMILE = 'FIRSTMILE'

    FASTWAY_IR = 'FASTWAY_IR'

    HH_EXP = 'HH_EXP'

    MYS_MYPOST_ONLINE = 'MYS_MYPOST_ONLINE'

    TNT_NL = 'TNT_NL'

    TIPSA = 'TIPSA'

    TAQBIN_MY = 'TAQBIN_MY'

    KGMHUB = 'KGMHUB'

    INTEXPRESS = 'INTEXPRESS'

    OVERSE_EXP = 'OVERSE_EXP'

    ONECLICK = 'ONECLICK'

    ROADRUNNER_FREIGHT = 'ROADRUNNER_FREIGHT'

    GLS_CROTIA = 'GLS_CROTIA'

    MRW_FTP = 'MRW_FTP'

    BLUEX = 'BLUEX'

    DYLT = 'DYLT'

    DPD_IR = 'DPD_IR'

    SIN_GLBL = 'SIN_GLBL'

    TUFFNELLS_REFERENCE = 'TUFFNELLS_REFERENCE'

    CJPACKET = 'CJPACKET'

    MILKMAN = 'MILKMAN'

    ASIGNA = 'ASIGNA'

    ONEWORLDEXPRESS = 'ONEWORLDEXPRESS'

    ROYAL_MAIL = 'ROYAL_MAIL'

    VIA_EXPRESS = 'VIA_EXPRESS'

    TIGFREIGHT = 'TIGFREIGHT'

    ZTO_EXPRESS = 'ZTO_EXPRESS'

    TWO_GO = 'TWO_GO'

    IML = 'IML'

    INTEL_VALLEY = 'INTEL_VALLEY'

    EFS = 'EFS'

    UK_UK_MAIL = 'UK_UK_MAIL'

    RAM = 'RAM'

    ALLIEDEXPRESS = 'ALLIEDEXPRESS'

    APC_OVERNIGHT = 'APC_OVERNIGHT'

    SHIPPIT = 'SHIPPIT'

    TFM = 'TFM'

    M_XPRESS = 'M_XPRESS'

    HDB_BOX = 'HDB_BOX'

    CLEVY_LINKS = 'CLEVY_LINKS'

    IBEONE = 'IBEONE'

    FIEGE_NL = 'FIEGE_NL'

    KWE_GLOBAL = 'KWE_GLOBAL'

    CTC_EXPRESS = 'CTC_EXPRESS'

    LAO_POST = 'LAO_POST'

    AMAZON = 'AMAZON'

    MORE_LINK = 'MORE_LINK'

    JX = 'JX'

    EASY_MAIL = 'EASY_MAIL'

    ADUIEPYLE = 'ADUIEPYLE'

    GB_PANTHER = 'GB_PANTHER'

    EXPRESSSALE = 'EXPRESSSALE'

    SG_DETRACK = 'SG_DETRACK'

    TRUNKRS_WEBHOOK = 'TRUNKRS_WEBHOOK'

    MATDESPATCH = 'MATDESPATCH'

    DICOM = 'DICOM'

    MBW = 'MBW'

    KHM_CAMBODIA_POST = 'KHM_CAMBODIA_POST'

    SINOTRANS = 'SINOTRANS'

    BRT_IT_PARCELID = 'BRT_IT_PARCELID'

    DHL_SUPPLY_CHAIN = 'DHL_SUPPLY_CHAIN'

    DHL_PL = 'DHL_PL'

    TOPYOU = 'TOPYOU'

    PALEXPRESS = 'PALEXPRESS'

    DHL_SG = 'DHL_SG'

    CN_WEDO = 'CN_WEDO'

    FULFILLME = 'FULFILLME'

    DPD_DELISTRACK = 'DPD_DELISTRACK'

    UPS_REFERENCE = 'UPS_REFERENCE'

    CARIBOU = 'CARIBOU'

    LOCUS_WEBHOOK = 'LOCUS_WEBHOOK'

    DSV = 'DSV'

    CN_GOFLY = 'CN_GOFLY'

    P2P_TRC = 'P2P_TRC'

    DIRECTPARCELS = 'DIRECTPARCELS'

    NOVA_POSHTA_INT = 'NOVA_POSHTA_INT'

    FEDEX_POLAND = 'FEDEX_POLAND'

    CN_JCEX = 'CN_JCEX'

    FAR_INTERNATIONAL = 'FAR_INTERNATIONAL'

    IDEXPRESS = 'IDEXPRESS'

    GANGBAO = 'GANGBAO'

    NEWAY = 'NEWAY'

    POSTNL_INT_3_S = 'POSTNL_INT_3_S'

    RPX_ID = 'RPX_ID'

    DESIGNERTRANSPORT_WEBHOOK = 'DESIGNERTRANSPORT_WEBHOOK'

    GLS_SLOVEN = 'GLS_SLOVEN'

    PARCELLED_IN = 'PARCELLED_IN'

    GSI_EXPRESS = 'GSI_EXPRESS'

    CON_WAY = 'CON_WAY'

    BROUWER_TRANSPORT = 'BROUWER_TRANSPORT'

    CPEX = 'CPEX'

    ISRAEL_POST = 'ISRAEL_POST'

    DTDC_IN = 'DTDC_IN'

    PTT_POST = 'PTT_POST'

    XDE_WEBHOOK = 'XDE_WEBHOOK'

    TOLOS = 'TOLOS'

    GIAO_HANG = 'GIAO_HANG'

    GEODIS_ESPACE = 'GEODIS_ESPACE'

    MAGYAR_HU = 'MAGYAR_HU'

    DOORDASH_WEBHOOK = 'DOORDASH_WEBHOOK'

    TIKI_ID = 'TIKI_ID'

    CJ_HK_INTERNATIONAL = 'CJ_HK_INTERNATIONAL'

    STAR_TRACK_EXPRESS = 'STAR_TRACK_EXPRESS'

    HELTHJEM = 'HELTHJEM'

    SFB2C = 'SFB2C'

    FREIGHTQUOTE = 'FREIGHTQUOTE'

    LANDMARK_GLOBAL_REFERENCE = 'LANDMARK_GLOBAL_REFERENCE'

    PARCEL2GO = 'PARCEL2GO'

    DELNEXT = 'DELNEXT'

    RCL = 'RCL'

    CGS_EXPRESS = 'CGS_EXPRESS'

    HK_POST = 'HK_POST'

    SAP_EXPRESS = 'SAP_EXPRESS'

    PARCELPOST_SG = 'PARCELPOST_SG'

    HERMES = 'HERMES'

    IND_SAFEEXPRESS = 'IND_SAFEEXPRESS'

    TOPHATTEREXPRESS = 'TOPHATTEREXPRESS'

    MGLOBAL = 'MGLOBAL'

    AVERITT = 'AVERITT'

    LEADER = 'LEADER'

    _2EBOX = '_2EBOX'

    SG_SPEEDPOST = 'SG_SPEEDPOST'

    DBSCHENKER_SE = 'DBSCHENKER_SE'

    ISR_POST_DOMESTIC = 'ISR_POST_DOMESTIC'

    BESTWAYPARCEL = 'BESTWAYPARCEL'

    ASENDIA_DE = 'ASENDIA_DE'

    NIGHTLINE_UK = 'NIGHTLINE_UK'

    TAQBIN_SG = 'TAQBIN_SG'

    TCK_EXPRESS = 'TCK_EXPRESS'

    ENDEAVOUR_DELIVERY = 'ENDEAVOUR_DELIVERY'

    NANJINGWOYUAN = 'NANJINGWOYUAN'

    HEPPNER_FR = 'HEPPNER_FR'

    EMPS_CN = 'EMPS_CN'

    FONSEN = 'FONSEN'

    PICKRR = 'PICKRR'

    APC_OVERNIGHT_CONNUM = 'APC_OVERNIGHT_CONNUM'

    STAR_TRACK_NEXT_FLIGHT = 'STAR_TRACK_NEXT_FLIGHT'

    DAJIN = 'DAJIN'

    UPS_FREIGHT = 'UPS_FREIGHT'

    POSTA_PLUS = 'POSTA_PLUS'

    CEVA = 'CEVA'

    ANSERX = 'ANSERX'

    JS_EXPRESS = 'JS_EXPRESS'

    PADTF = 'PADTF'

    UPS_MAIL_INNOVATIONS = 'UPS_MAIL_INNOVATIONS'

    EZSHIP = 'EZSHIP'

    SYPOST = 'SYPOST'

    AMAZON_SHIP_MCF = 'AMAZON_SHIP_MCF'

    YUSEN = 'YUSEN'

    BRING = 'BRING'

    SDA_IT = 'SDA_IT'

    GBA = 'GBA'

    NEWEGGEXPRESS = 'NEWEGGEXPRESS'

    SPEEDCOURIERS_GR = 'SPEEDCOURIERS_GR'

    FORRUN = 'FORRUN'

    PICKUP = 'PICKUP'

    ECMS = 'ECMS'

    INTELIPOST = 'INTELIPOST'

    FLASHEXPRESS = 'FLASHEXPRESS'

    CN_STO = 'CN_STO'

    SEKO_SFTP = 'SEKO_SFTP'

    HOME_DELIVERY_SOLUTIONS = 'HOME_DELIVERY_SOLUTIONS'

    DPD_HGRY = 'DPD_HGRY'

    KERRYTTC_VN = 'KERRYTTC_VN'

    JOYING_BOX = 'JOYING_BOX'

    TOTAL_EXPRESS = 'TOTAL_EXPRESS'

    ZJS_EXPRESS = 'ZJS_EXPRESS'

    STARKEN = 'STARKEN'

    DEMANDSHIP = 'DEMANDSHIP'

    CN_DPEX = 'CN_DPEX'

    AUPOST_CN = 'AUPOST_CN'

    LOGISTERS = 'LOGISTERS'

    GOGLOBALPOST = 'GOGLOBALPOST'

    GLS_CZ = 'GLS_CZ'

    PAACK_WEBHOOK = 'PAACK_WEBHOOK'

    GRAB_WEBHOOK = 'GRAB_WEBHOOK'

    PARCELPOINT = 'PARCELPOINT'

    ICUMULUS = 'ICUMULUS'

    DAIGLOBALTRACK = 'DAIGLOBALTRACK'

    GLOBAL_IPARCEL = 'GLOBAL_IPARCEL'

    YURTICI_KARGO = 'YURTICI_KARGO'

    CN_PAYPAL_PACKAGE = 'CN_PAYPAL_PACKAGE'

    PARCEL_2_POST = 'PARCEL_2_POST'

    GLS_IT = 'GLS_IT'

    PIL_LOGISTICS = 'PIL_LOGISTICS'

    HEPPNER = 'HEPPNER'

    GENERAL_OVERNIGHT = 'GENERAL_OVERNIGHT'

    HAPPY2POINT = 'HAPPY2POINT'

    CHITCHATS = 'CHITCHATS'

    SMOOTH = 'SMOOTH'

    CLE_LOGISTICS = 'CLE_LOGISTICS'

    FIEGE = 'FIEGE'

    MX_CARGO = 'MX_CARGO'

    ZIINGFINALMILE = 'ZIINGFINALMILE'

    DAYTON_FREIGHT = 'DAYTON_FREIGHT'

    TCS = 'TCS'

    AEX = 'AEX'

    HERMES_DE = 'HERMES_DE'

    ROUTIFIC_WEBHOOK = 'ROUTIFIC_WEBHOOK'

    GLOBAVEND = 'GLOBAVEND'

    CJ_LOGISTICS = 'CJ_LOGISTICS'

    PALLET_NETWORK = 'PALLET_NETWORK'

    RAF_PH = 'RAF_PH'

    UK_XDP = 'UK_XDP'

    PAPER_EXPRESS = 'PAPER_EXPRESS'

    LA_POSTE_SUIVI = 'LA_POSTE_SUIVI'

    PAQUETEXPRESS = 'PAQUETEXPRESS'

    LIEFERY = 'LIEFERY'

    STRECK_TRANSPORT = 'STRECK_TRANSPORT'

    PONY_EXPRESS = 'PONY_EXPRESS'

    ALWAYS_EXPRESS = 'ALWAYS_EXPRESS'

    GBS_BROKER = 'GBS_BROKER'

    CITYLINK_MY = 'CITYLINK_MY'

    ALLJOY = 'ALLJOY'

    YODEL = 'YODEL'

    YODEL_DIR = 'YODEL_DIR'

    STONE3PL = 'STONE3PL'

    PARCELPAL_WEBHOOK = 'PARCELPAL_WEBHOOK'

    DHL_ECOMERCE_ASA = 'DHL_ECOMERCE_ASA'

    SIMPLYPOST = 'SIMPLYPOST'

    KY_EXPRESS = 'KY_EXPRESS'

    SHENZHEN = 'SHENZHEN'

    US_LASERSHIP = 'US_LASERSHIP'

    UC_EXPRE = 'UC_EXPRE'

    DIDADI = 'DIDADI'

    CJ_KR = 'CJ_KR'

    DBSCHENKER_B2B = 'DBSCHENKER_B2B'

    MXE = 'MXE'

    CAE_DELIVERS = 'CAE_DELIVERS'

    PFCEXPRESS = 'PFCEXPRESS'

    WHISTL = 'WHISTL'

    WEPOST = 'WEPOST'

    DHL_PARCEL_ES = 'DHL_PARCEL_ES'

    DDEXPRESS = 'DDEXPRESS'

    ARAMEX_AU = 'ARAMEX_AU'

    BNEED = 'BNEED'

    HK_TGX = 'HK_TGX'

    LATVIJAS_PASTS = 'LATVIJAS_PASTS'

    VIAEUROPE = 'VIAEUROPE'

    CORREO_UY = 'CORREO_UY'

    CHRONOPOST_FR = 'CHRONOPOST_FR'

    J_NET = 'J_NET'

    _6LS = '_6LS'

    BLR_BELPOST = 'BLR_BELPOST'

    BIRDSYSTEM = 'BIRDSYSTEM'

    DOBROPOST = 'DOBROPOST'

    WAHANA_ID = 'WAHANA_ID'

    WEASHIP = 'WEASHIP'

    SONICTL = 'SONICTL'

    KWT = 'KWT'

    AFLLOG_FTP = 'AFLLOG_FTP'

    SKYNET_WORLDWIDE = 'SKYNET_WORLDWIDE'

    NOVA_POSHTA = 'NOVA_POSHTA'

    SEINO = 'SEINO'

    SZENDEX = 'SZENDEX'

    BPOST_INT = 'BPOST_INT'

    DBSCHENKER_SV = 'DBSCHENKER_SV'

    AO_DEUTSCHLAND = 'AO_DEUTSCHLAND'

    EU_FLEET_SOLUTIONS = 'EU_FLEET_SOLUTIONS'

    PCFCORP = 'PCFCORP'

    LINKBRIDGE = 'LINKBRIDGE'

    PRIMAMULTICIPTA = 'PRIMAMULTICIPTA'

    COUREX = 'COUREX'

    ZAJIL_EXPRESS = 'ZAJIL_EXPRESS'

    COLLECTCO = 'COLLECTCO'

    JTEXPRESS = 'JTEXPRESS'

    FEDEX_UK = 'FEDEX_UK'

    USHIP = 'USHIP'

    PIXSELL = 'PIXSELL'

    SHIPTOR = 'SHIPTOR'

    CDEK = 'CDEK'

    VNM_VIETTELPOST = 'VNM_VIETTELPOST'

    CJ_CENTURY = 'CJ_CENTURY'

    GSO = 'GSO'

    VIWO = 'VIWO'

    SKYBOX = 'SKYBOX'

    KERRYTJ = 'KERRYTJ'

    NTLOGISTICS_VN = 'NTLOGISTICS_VN'

    SDH_SCM = 'SDH_SCM'

    ZINC = 'ZINC'

    DPE_SOUTH_AFRC = 'DPE_SOUTH_AFRC'

    CESKA_CZ = 'CESKA_CZ'

    ACS_GR = 'ACS_GR'

    DEALERSEND = 'DEALERSEND'

    JOCOM = 'JOCOM'

    CSE = 'CSE'

    TFORCE_FINALMILE = 'TFORCE_FINALMILE'

    SHIP_GATE = 'SHIP_GATE'

    SHIPTER = 'SHIPTER'

    NATIONAL_SAMEDAY = 'NATIONAL_SAMEDAY'

    YUNEXPRESS = 'YUNEXPRESS'

    CAINIAO = 'CAINIAO'

    DMS_MATRIX = 'DMS_MATRIX'

    DIRECTLOG = 'DIRECTLOG'

    ASENDIA_US = 'ASENDIA_US'

    _3JMSLOGISTICS = '_3JMSLOGISTICS'

    LICCARDI_EXPRESS = 'LICCARDI_EXPRESS'

    SKY_POSTAL = 'SKY_POSTAL'

    CNWANGTONG = 'CNWANGTONG'

    POSTNORD_LOGISTICS_DK = 'POSTNORD_LOGISTICS_DK'

    LOGISTIKA = 'LOGISTIKA'

    CELERITAS = 'CELERITAS'

    PRESSIODE = 'PRESSIODE'

    SHREE_MARUTI = 'SHREE_MARUTI'

    LOGISTICSWORLDWIDE_HK = 'LOGISTICSWORLDWIDE_HK'

    EFEX = 'EFEX'

    LOTTE = 'LOTTE'

    LONESTAR = 'LONESTAR'

    APRISAEXPRESS = 'APRISAEXPRESS'

    BEL_RS = 'BEL_RS'

    OSM_WORLDWIDE = 'OSM_WORLDWIDE'

    WESTGATE_GL = 'WESTGATE_GL'

    FASTRACK = 'FASTRACK'

    DTD_EXPR = 'DTD_EXPR'

    ALFATREX = 'ALFATREX'

    PROMEDDELIVERY = 'PROMEDDELIVERY'

    THABIT_LOGISTICS = 'THABIT_LOGISTICS'

    HCT_LOGISTICS = 'HCT_LOGISTICS'

    CARRY_FLAP = 'CARRY_FLAP'

    US_OLD_DOMINION = 'US_OLD_DOMINION'

    ANICAM_BOX = 'ANICAM_BOX'

    WANBEXPRESS = 'WANBEXPRESS'

    AN_POST = 'AN_POST'

    DPD_LOCAL = 'DPD_LOCAL'

    STALLIONEXPRESS = 'STALLIONEXPRESS'

    RAIDEREX = 'RAIDEREX'

    SHOPFANS = 'SHOPFANS'

    KYUNGDONG_PARCEL = 'KYUNGDONG_PARCEL'

    CHAMPION_LOGISTICS = 'CHAMPION_LOGISTICS'

    PICKUPP_SGP = 'PICKUPP_SGP'

    MORNING_EXPRESS = 'MORNING_EXPRESS'

    NACEX = 'NACEX'

    THENILE_WEBHOOK = 'THENILE_WEBHOOK'

    HOLISOL = 'HOLISOL'

    LBCEXPRESS_FTP = 'LBCEXPRESS_FTP'

    KURASI = 'KURASI'

    USF_REDDAWAY = 'USF_REDDAWAY'

    APG = 'APG'

    CN_BOXC = 'CN_BOXC'

    ECOSCOOTING = 'ECOSCOOTING'

    MAINWAY = 'MAINWAY'

    PAPERFLY = 'PAPERFLY'

    HOUNDEXPRESS = 'HOUNDEXPRESS'

    BOX_BERRY = 'BOX_BERRY'

    EP_BOX = 'EP_BOX'

    PLUS_LOG_UK = 'PLUS_LOG_UK'

    FULFILLA = 'FULFILLA'

    ASE = 'ASE'

    MAIL_PLUS = 'MAIL_PLUS'

    XPO_LOGISTICS = 'XPO_LOGISTICS'

    WNDIRECT = 'WNDIRECT'

    CLOUDWISH_ASIA = 'CLOUDWISH_ASIA'

    ZELERIS = 'ZELERIS'

    GIO_EXPRESS = 'GIO_EXPRESS'

    OCS_WORLDWIDE = 'OCS_WORLDWIDE'

    ARK_LOGISTICS = 'ARK_LOGISTICS'

    AQUILINE = 'AQUILINE'

    PILOT_FREIGHT = 'PILOT_FREIGHT'

    QWINTRY = 'QWINTRY'

    DANSKE_FRAGT = 'DANSKE_FRAGT'

    CARRIERS = 'CARRIERS'

    AIR_CANADA_GLOBAL = 'AIR_CANADA_GLOBAL'

    PRESIDENT_TRANS = 'PRESIDENT_TRANS'

    STEPFORWARDFS = 'STEPFORWARDFS'

    SKYNET_UK = 'SKYNET_UK'

    PITTOHIO = 'PITTOHIO'

    CORREOS_EXPRESS = 'CORREOS_EXPRESS'

    RL_US = 'RL_US'

    MARA_XPRESS = 'MARA_XPRESS'

    DESTINY = 'DESTINY'

    UK_YODEL = 'UK_YODEL'

    COMET_TECH = 'COMET_TECH'

    DHL_PARCEL_RU = 'DHL_PARCEL_RU'

    TNT_REFR = 'TNT_REFR'

    SHREE_ANJANI_COURIER = 'SHREE_ANJANI_COURIER'

    MIKROPAKKET_BE = 'MIKROPAKKET_BE'

    ETS_EXPRESS = 'ETS_EXPRESS'

    COLIS_PRIVE = 'COLIS_PRIVE'

    CN_YUNDA = 'CN_YUNDA'

    AAA_COOPER = 'AAA_COOPER'

    ROCKET_PARCEL = 'ROCKET_PARCEL'

    _360LION = '_360LION'

    PANDU = 'PANDU'

    PROFESSIONAL_COURIERS = 'PROFESSIONAL_COURIERS'

    FLYTEXPRESS = 'FLYTEXPRESS'

    LOGISTICSWORLDWIDE_MY = 'LOGISTICSWORLDWIDE_MY'

    CORREOS_DE_ESPANA = 'CORREOS_DE_ESPANA'

    IMX = 'IMX'

    FOUR_PX_EXPRESS = 'FOUR_PX_EXPRESS'

    XPRESSBEES = 'XPRESSBEES'

    PICKUPP_VNM = 'PICKUPP_VNM'

    STARTRACK_EXPRESS1 = 'STARTRACK_EXPRESS'

    FR_COLISSIMO = 'FR_COLISSIMO'

    NACEX_SPAIN_REFERENCE = 'NACEX_SPAIN_REFERENCE'

    DHL_SUPPLY_CHAIN_AU = 'DHL_SUPPLY_CHAIN_AU'

    ESHIPPING = 'ESHIPPING'

    SHREETIRUPATI = 'SHREETIRUPATI'

    HX_EXPRESS = 'HX_EXPRESS'

    INDOPAKET = 'INDOPAKET'

    CN_17POST = 'CN_17POST'

    K1_EXPRESS = 'K1_EXPRESS'

    CJ_GLS = 'CJ_GLS'

    MYS_GDEX = 'MYS_GDEX'

    NATIONEX = 'NATIONEX'

    ANJUN = 'ANJUN'

    FARGOOD = 'FARGOOD'

    SMG_EXPRESS = 'SMG_EXPRESS'

    RZYEXPRESS = 'RZYEXPRESS'

    SEFL = 'SEFL'

    TNT_CLICK_IT = 'TNT_CLICK_IT'

    HDB = 'HDB'

    HIPSHIPPER = 'HIPSHIPPER'

    RPXLOGISTICS = 'RPXLOGISTICS'

    KUEHNE = 'KUEHNE'

    IT_NEXIVE = 'IT_NEXIVE'

    PTS = 'PTS'

    SWISS_POST_FTP = 'SWISS_POST_FTP'

    FASTRK_SERV = 'FASTRK_SERV'

    _4_72 = '_4_72'

    US_YRC = 'US_YRC'

    POSTNL_INTL_3S = 'POSTNL_INTL_3S'

    ELIAN_POST = 'ELIAN_POST'

    CUBYN = 'CUBYN'

    SAU_SAUDI_POST = 'SAU_SAUDI_POST'

    ABXEXPRESS_MY = 'ABXEXPRESS_MY'

    HUAHAN_EXPRESS = 'HUAHAN_EXPRESS'

    IND_JAYONEXPRESS = 'IND_JAYONEXPRESS'

    ZES_EXPRESS = 'ZES_EXPRESS'

    ZEPTO_EXPRESS = 'ZEPTO_EXPRESS'

    SKYNET_ZA = 'SKYNET_ZA'

    ZEEK_2_DOOR = 'ZEEK_2_DOOR'

    BLINKLASTMILE = 'BLINKLASTMILE'

    POSTA_UKR = 'POSTA_UKR'

    CHROBINSON = 'CHROBINSON'

    CN_POST56 = 'CN_POST56'

    COURANT_PLUS = 'COURANT_PLUS'

    SCUDEX_EXPRESS = 'SCUDEX_EXPRESS'

    SHIPENTEGRA = 'SHIPENTEGRA'

    B_TWO_C_EUROPE = 'B_TWO_C_EUROPE'

    COPE = 'COPE'

    IND_GATI = 'IND_GATI'

    CN_WISHPOST = 'CN_WISHPOST'

    NACEX_ES = 'NACEX_ES'

    TAQBIN_HK = 'TAQBIN_HK'

    GLOBALTRANZ = 'GLOBALTRANZ'

    HKD = 'HKD'

    BJSHOMEDELIVERY = 'BJSHOMEDELIVERY'

    OMNIVA = 'OMNIVA'

    SUTTON = 'SUTTON'

    PANTHER_REFERENCE = 'PANTHER_REFERENCE'

    SFCSERVICE = 'SFCSERVICE'

    LTL = 'LTL'

    PARKNPARCEL = 'PARKNPARCEL'

    SPRING_GDS = 'SPRING_GDS'

    ECEXPRESS = 'ECEXPRESS'

    INTERPARCEL_AU = 'INTERPARCEL_AU'

    AGILITY = 'AGILITY'

    XL_EXPRESS = 'XL_EXPRESS'

    ADERONLINE = 'ADERONLINE'

    DIRECTCOURIERS = 'DIRECTCOURIERS'

    PLANZER = 'PLANZER'

    SENDING = 'SENDING'

    NINJAVAN_WB = 'NINJAVAN_WB'

    NATIONWIDE_MY = 'NATIONWIDE_MY'

    SENDIT = 'SENDIT'

    GB_ARROW = 'GB_ARROW'

    IND_GOJAVAS = 'IND_GOJAVAS'

    KPOST = 'KPOST'

    DHL_FREIGHT = 'DHL_FREIGHT'

    BLUECARE = 'BLUECARE'

    JINDOUYUN = 'JINDOUYUN'

    TRACKON = 'TRACKON'

    GB_TUFFNELLS = 'GB_TUFFNELLS'

    TRUMPCARD = 'TRUMPCARD'

    ETOTAL = 'ETOTAL'

    SFPLUS_WEBHOOK = 'SFPLUS_WEBHOOK'

    SEKOLOGISTICS = 'SEKOLOGISTICS'

    HERMES_2MANN_HANDLING = 'HERMES_2MANN_HANDLING'

    DPD_LOCAL_REF = 'DPD_LOCAL_REF'

    UDS = 'UDS'

    ZA_SPECIALISED_FREIGHT = 'ZA_SPECIALISED_FREIGHT'

    THA_KERRY = 'THA_KERRY'

    PRT_INT_SEUR = 'PRT_INT_SEUR'

    BRA_CORREIOS = 'BRA_CORREIOS'

    NZ_NZ_POST = 'NZ_NZ_POST'

    CN_EQUICK = 'CN_EQUICK'

    MYS_EMS = 'MYS_EMS'

    GB_NORSK = 'GB_NORSK'

    ESP_MRW = 'ESP_MRW'

    ESP_PACKLINK = 'ESP_PACKLINK'

    KANGAROO_MY = 'KANGAROO_MY'

    RPX = 'RPX'

    XDP_UK_REFERENCE = 'XDP_UK_REFERENCE'

    NINJAVAN_MY = 'NINJAVAN_MY'

    ADICIONAL = 'ADICIONAL'

    NINJAVAN_ID = 'NINJAVAN_ID'

    ROADBULL = 'ROADBULL'

    YAKIT = 'YAKIT'

    MAILAMERICAS = 'MAILAMERICAS'

    MIKROPAKKET = 'MIKROPAKKET'

    DYNALOGIC = 'DYNALOGIC'

    DHL_ES = 'DHL_ES'

    DHL_PARCEL_NL = 'DHL_PARCEL_NL'

    DHL_GLOBAL_MAIL_ASIA = 'DHL_GLOBAL_MAIL_ASIA'

    DAWN_WING = 'DAWN_WING'

    GENIKI_GR = 'GENIKI_GR'

    HERMESWORLD_UK = 'HERMESWORLD_UK'

    ALPHAFAST = 'ALPHAFAST'

    BUYLOGIC = 'BUYLOGIC'

    EKART = 'EKART'

    MEX_SENDA = 'MEX_SENDA'

    SFC_LOGISTICS = 'SFC_LOGISTICS'

    POST_SERBIA = 'POST_SERBIA'

    IND_DELHIVERY = 'IND_DELHIVERY'

    DE_DPD_DELISTRACK = 'DE_DPD_DELISTRACK'

    RPD2MAN = 'RPD2MAN'

    CN_SF_EXPRESS = 'CN_SF_EXPRESS'

    YANWEN = 'YANWEN'

    MYS_SKYNET = 'MYS_SKYNET'

    CORREOS_DE_MEXICO = 'CORREOS_DE_MEXICO'

    CBL_LOGISTICA = 'CBL_LOGISTICA'

    MEX_ESTAFETA = 'MEX_ESTAFETA'

    AU_AUSTRIAN_POST = 'AU_AUSTRIAN_POST'

    RINCOS = 'RINCOS'

    NLD_DHL = 'NLD_DHL'

    RUSSIAN_POST = 'RUSSIAN_POST'

    COURIERS_PLEASE = 'COURIERS_PLEASE'

    POSTNORD_LOGISTICS = 'POSTNORD_LOGISTICS'

    FEDEX = 'FEDEX'

    DPE_EXPRESS = 'DPE_EXPRESS'

    DPD = 'DPD'

    ADSONE = 'ADSONE'

    IDN_JNE = 'IDN_JNE'

    THECOURIERGUY = 'THECOURIERGUY'

    CNEXPS = 'CNEXPS'

    PRT_CHRONOPOST = 'PRT_CHRONOPOST'

    LANDMARK_GLOBAL = 'LANDMARK_GLOBAL'

    IT_DHL_ECOMMERCE = 'IT_DHL_ECOMMERCE'

    ESP_NACEX = 'ESP_NACEX'

    PRT_CTT = 'PRT_CTT'

    BE_KIALA = 'BE_KIALA'

    ASENDIA_UK = 'ASENDIA_UK'

    GLOBAL_TNT = 'GLOBAL_TNT'

    POSTUR_IS = 'POSTUR_IS'

    EPARCEL_KR = 'EPARCEL_KR'

    INPOST_PACZKOMATY = 'INPOST_PACZKOMATY'

    IT_POSTE_ITALIA = 'IT_POSTE_ITALIA'

    BE_BPOST = 'BE_BPOST'

    PL_POCZTA_POLSKA = 'PL_POCZTA_POLSKA'

    MYS_MYS_POST = 'MYS_MYS_POST'

    SG_SG_POST = 'SG_SG_POST'

    THA_THAILAND_POST = 'THA_THAILAND_POST'

    LEXSHIP = 'LEXSHIP'

    FASTWAY_NZ = 'FASTWAY_NZ'

    DHL_AU = 'DHL_AU'

    COSTMETICSNOW = 'COSTMETICSNOW'

    PFLOGISTICS = 'PFLOGISTICS'

    LOOMIS_EXPRESS = 'LOOMIS_EXPRESS'

    GLS_ITALY = 'GLS_ITALY'

    LINE = 'LINE'

    GEL_EXPRESS = 'GEL_EXPRESS'

    HUODULL = 'HUODULL'

    NINJAVAN_SG = 'NINJAVAN_SG'

    JANIO = 'JANIO'

    AO_COURIER = 'AO_COURIER'

    BRT_IT_SENDER_REF = 'BRT_IT_SENDER_REF'

    SAILPOST = 'SAILPOST'

    LALAMOVE = 'LALAMOVE'

    NEWZEALAND_COURIERS = 'NEWZEALAND_COURIERS'

    ETOMARS = 'ETOMARS'

    VIRTRANSPORT = 'VIRTRANSPORT'

    WIZMO = 'WIZMO'

    PALLETWAYS = 'PALLETWAYS'

    I_DIKA = 'I_DIKA'

    CFL_LOGISTICS = 'CFL_LOGISTICS'

    GEMWORLDWIDE = 'GEMWORLDWIDE'

    GLOBAL_EXPRESS = 'GLOBAL_EXPRESS'

    LOGISTYX_TRANSGROUP = 'LOGISTYX_TRANSGROUP'

    WESTBANK_COURIER = 'WESTBANK_COURIER'

    ARCO_SPEDIZIONI = 'ARCO_SPEDIZIONI'

    YDH_EXPRESS = 'YDH_EXPRESS'

    PARCELINKLOGISTICS = 'PARCELINKLOGISTICS'

    CNDEXPRESS = 'CNDEXPRESS'

    NOX_NIGHT_TIME_EXPRESS = 'NOX_NIGHT_TIME_EXPRESS'

    AERONET = 'AERONET'

    LTIANEXP = 'LTIANEXP'

    INTEGRA2_FTP = 'INTEGRA2_FTP'

    PARCELONE = 'PARCELONE'

    NOX_NACHTEXPRESS = 'NOX_NACHTEXPRESS'

    CN_CHINA_POST_EMS = 'CN_CHINA_POST_EMS'

    CHUKOU1 = 'CHUKOU1'

    GLS_SLOV = 'GLS_SLOV'

    ORANGE_DS = 'ORANGE_DS'

    JOOM_LOGIS = 'JOOM_LOGIS'

    AUS_STARTRACK = 'AUS_STARTRACK'

    DHL = 'DHL'

    GB_APC = 'GB_APC'

    BONDSCOURIERS = 'BONDSCOURIERS'

    JPN_JAPAN_POST = 'JPN_JAPAN_POST'

    USPS = 'USPS'

    WINIT = 'WINIT'

    ARG_OCA = 'ARG_OCA'

    TW_TAIWAN_POST = 'TW_TAIWAN_POST'

    DMM_NETWORK = 'DMM_NETWORK'

    TNT = 'TNT'

    BH_POSTA = 'BH_POSTA'

    SWE_POSTNORD = 'SWE_POSTNORD'

    CA_CANADA_POST = 'CA_CANADA_POST'

    WISELOADS = 'WISELOADS'

    ASENDIA_HK = 'ASENDIA_HK'

    NLD_GLS = 'NLD_GLS'

    MEX_REDPACK = 'MEX_REDPACK'

    JET_SHIP = 'JET_SHIP'

    DE_DHL_EXPRESS = 'DE_DHL_EXPRESS'

    NINJAVAN_THAI = 'NINJAVAN_THAI'

    RABEN_GROUP = 'RABEN_GROUP'

    ESP_ASM = 'ESP_ASM'

    HRV_HRVATSKA = 'HRV_HRVATSKA'

    GLOBAL_ESTES = 'GLOBAL_ESTES'

    LTU_LIETUVOS = 'LTU_LIETUVOS'

    BEL_DHL = 'BEL_DHL'

    AU_AU_POST = 'AU_AU_POST'

    SPEEDEXCOURIER = 'SPEEDEXCOURIER'

    FR_COLIS = 'FR_COLIS'

    ARAMEX = 'ARAMEX'

    DPEX = 'DPEX'

    MYS_AIRPAK = 'MYS_AIRPAK'

    CUCKOOEXPRESS = 'CUCKOOEXPRESS'

    DPD_POLAND = 'DPD_POLAND'

    NLD_POSTNL = 'NLD_POSTNL'

    NIM_EXPRESS = 'NIM_EXPRESS'

    QUANTIUM = 'QUANTIUM'

    SENDLE = 'SENDLE'

    ESP_REDUR = 'ESP_REDUR'

    MATKAHUOLTO = 'MATKAHUOLTO'

    CPACKET = 'CPACKET'

    POSTI = 'POSTI'

    HUNTER_EXPRESS = 'HUNTER_EXPRESS'

    CHOIR_EXP = 'CHOIR_EXP'

    LEGION_EXPRESS = 'LEGION_EXPRESS'

    AUSTRIAN_POST_EXPRESS = 'AUSTRIAN_POST_EXPRESS'

    GRUPO = 'GRUPO'

    POSTA_RO = 'POSTA_RO'

    INTERPARCEL_UK = 'INTERPARCEL_UK'

    GLOBAL_ABF = 'GLOBAL_ABF'

    POSTEN_NORGE = 'POSTEN_NORGE'

    XPERT_DELIVERY = 'XPERT_DELIVERY'

    DHL_REFR = 'DHL_REFR'

    DHL_HK = 'DHL_HK'

    SKYNET_UAE = 'SKYNET_UAE'

    GOJEK = 'GOJEK'

    YODEL_INTNL = 'YODEL_INTNL'

    JANCO = 'JANCO'

    YTO = 'YTO'

    WISE_EXPRESS = 'WISE_EXPRESS'

    JTEXPRESS_VN = 'JTEXPRESS_VN'

    FEDEX_INTL_MLSERV = 'FEDEX_INTL_MLSERV'

    VAMOX = 'VAMOX'

    AMS_GRP = 'AMS_GRP'

    DHL_JP = 'DHL_JP'

    HRPARCEL = 'HRPARCEL'

    GESWL = 'GESWL'

    BLUESTAR = 'BLUESTAR'

    CDEK_TR = 'CDEK_TR'

    DESCARTES = 'DESCARTES'

    DELTEC_UK = 'DELTEC_UK'

    DTDC_EXPRESS = 'DTDC_EXPRESS'

    TOURLINE = 'TOURLINE'

    BH_WORLDWIDE = 'BH_WORLDWIDE'

    OCS = 'OCS'

    YINGNUO_LOGISTICS = 'YINGNUO_LOGISTICS'

    UPS = 'UPS'

    TOLL = 'TOLL'

    PRT_SEUR = 'PRT_SEUR'

    DTDC_AU = 'DTDC_AU'

    THA_DYNAMIC_LOGISTICS = 'THA_DYNAMIC_LOGISTICS'

    UBI_LOGISTICS = 'UBI_LOGISTICS'

    FEDEX_CROSSBORDER = 'FEDEX_CROSSBORDER'

    A1POST = 'A1POST'

    TAZMANIAN_FREIGHT = 'TAZMANIAN_FREIGHT'

    CJ_INT_MY = 'CJ_INT_MY'

    SAIA_FREIGHT = 'SAIA_FREIGHT'

    SG_QXPRESS = 'SG_QXPRESS'

    NHANS_SOLUTIONS = 'NHANS_SOLUTIONS'

    DPD_FR = 'DPD_FR'

    COORDINADORA = 'COORDINADORA'

    ANDREANI = 'ANDREANI'

    DOORA = 'DOORA'

    INTERPARCEL_NZ = 'INTERPARCEL_NZ'

    PHL_JAMEXPRESS = 'PHL_JAMEXPRESS'

    BEL_BELGIUM_POST = 'BEL_BELGIUM_POST'

    US_APC = 'US_APC'

    IDN_POS = 'IDN_POS'

    FR_MONDIAL = 'FR_MONDIAL'

    DE_DHL = 'DE_DHL'

    HK_RPX = 'HK_RPX'

    DHL_PIECEID = 'DHL_PIECEID'

    VNPOST_EMS = 'VNPOST_EMS'

    RRDONNELLEY = 'RRDONNELLEY'

    DPD_DE = 'DPD_DE'

    DELCART_IN = 'DELCART_IN'

    IMEXGLOBALSOLUTIONS = 'IMEXGLOBALSOLUTIONS'

    ACOMMERCE = 'ACOMMERCE'

    EURODIS = 'EURODIS'

    CANPAR = 'CANPAR'

    GLS = 'GLS'

    IND_ECOM = 'IND_ECOM'

    ESP_ENVIALIA = 'ESP_ENVIALIA'

    DHL_UK = 'DHL_UK'

    SMSA_EXPRESS = 'SMSA_EXPRESS'

    TNT_FR = 'TNT_FR'

    DEX_I = 'DEX_I'

    BUDBEE_WEBHOOK = 'BUDBEE_WEBHOOK'

    COPA_COURIER = 'COPA_COURIER'

    VNM_VIETNAM_POST = 'VNM_VIETNAM_POST'

    DPD_HK = 'DPD_HK'

    TOLL_NZ = 'TOLL_NZ'

    ECHO = 'ECHO'

    FEDEX_FR = 'FEDEX_FR'

    BORDEREXPRESS = 'BORDEREXPRESS'

    MAILPLUS_JPN = 'MAILPLUS_JPN'

    TNT_UK_REFR = 'TNT_UK_REFR'

    KEC = 'KEC'

    DPD_RO = 'DPD_RO'

    TNT_JP = 'TNT_JP'

    TH_CJ = 'TH_CJ'

    EC_CN = 'EC_CN'

    FASTWAY_UK = 'FASTWAY_UK'

    FASTWAY_US = 'FASTWAY_US'

    GLS_DE = 'GLS_DE'

    GLS_ES = 'GLS_ES'

    GLS_FR = 'GLS_FR'

    MONDIAL_BE = 'MONDIAL_BE'

    SGT_IT = 'SGT_IT'

    TNT_CN = 'TNT_CN'

    TNT_DE = 'TNT_DE'

    TNT_ES = 'TNT_ES'

    TNT_PL = 'TNT_PL'

    PARCELFORCE = 'PARCELFORCE'

    SWISS_POST = 'SWISS_POST'

    TOLL_IPEC = 'TOLL_IPEC'

    AIR_21 = 'AIR_21'

    AIRSPEED = 'AIRSPEED'

    BERT = 'BERT'

    BLUEDART = 'BLUEDART'

    COLLECTPLUS = 'COLLECTPLUS'

    COURIERPLUS = 'COURIERPLUS'

    COURIER_POST = 'COURIER_POST'

    DHL_GLOBAL_MAIL = 'DHL_GLOBAL_MAIL'

    DPD_UK = 'DPD_UK'

    DELTEC_DE = 'DELTEC_DE'

    DEUTSCHE_DE = 'DEUTSCHE_DE'

    DOTZOT = 'DOTZOT'

    ELTA_GR = 'ELTA_GR'

    EMS_CN = 'EMS_CN'

    ECARGO = 'ECARGO'

    ENSENDA = 'ENSENDA'

    FERCAM_IT = 'FERCAM_IT'

    FASTWAY_ZA = 'FASTWAY_ZA'

    FASTWAY_AU = 'FASTWAY_AU'

    FIRST_LOGISITCS = 'FIRST_LOGISITCS'

    GEODIS = 'GEODIS'

    GLOBEGISTICS = 'GLOBEGISTICS'

    GREYHOUND = 'GREYHOUND'

    JETSHIP_MY = 'JETSHIP_MY'

    LION_PARCEL = 'LION_PARCEL'

    AEROFLASH = 'AEROFLASH'

    ONTRAC = 'ONTRAC'

    SAGAWA = 'SAGAWA'

    SIODEMKA = 'SIODEMKA'

    STARTRACK = 'STARTRACK'

    TNT_AU = 'TNT_AU'

    TNT_IT = 'TNT_IT'

    TRANSMISSION = 'TRANSMISSION'

    YAMATO = 'YAMATO'

    DHL_IT = 'DHL_IT'

    DHL_AT = 'DHL_AT'

    LOGISTICSWORLDWIDE_KR = 'LOGISTICSWORLDWIDE_KR'

    GLS_SPAIN = 'GLS_SPAIN'

    AMAZON_UK_API = 'AMAZON_UK_API'

    DPD_FR_REFERENCE = 'DPD_FR_REFERENCE'

    DHLPARCEL_UK = 'DHLPARCEL_UK'

    MEGASAVE = 'MEGASAVE'

    QUALITYPOST = 'QUALITYPOST'

    IDS_LOGISTICS = 'IDS_LOGISTICS'

    JOYINGBOX1 = 'JOYINGBOX'

    PANTHER_ORDER_NUMBER = 'PANTHER_ORDER_NUMBER'

    WATKINS_SHEPARD = 'WATKINS_SHEPARD'

    FASTTRACK = 'FASTTRACK'

    UP_EXPRESS = 'UP_EXPRESS'

    ELOGISTICA = 'ELOGISTICA'

    ECOURIER = 'ECOURIER'

    CJ_PHILIPPINES = 'CJ_PHILIPPINES'

    SPEEDEX = 'SPEEDEX'

    ORANGECONNEX = 'ORANGECONNEX'

    TECOR = 'TECOR'

    SAEE = 'SAEE'

    GLS_ITALY_FTP = 'GLS_ITALY_FTP'

    DELIVERE = 'DELIVERE'

    YYCOM = 'YYCOM'

    ADICIONAL_PT = 'ADICIONAL_PT'

    DKSH = 'DKSH'

    NIPPON_EXPRESS_FTP = 'NIPPON_EXPRESS_FTP'

    GOLS = 'GOLS'

    FUJEXP = 'FUJEXP'

    QTRACK = 'QTRACK'

    OMLOGISTICS_API = 'OMLOGISTICS_API'

    GDPHARM = 'GDPHARM'

    MISUMI_CN = 'MISUMI_CN'

    AIR_CANADA = 'AIR_CANADA'

    CITY56_WEBHOOK = 'CITY56_WEBHOOK'

    SAGAWA_API = 'SAGAWA_API'

    KEDAEX = 'KEDAEX'

    PGEON_API = 'PGEON_API'

    WEWORLDEXPRESS = 'WEWORLDEXPRESS'

    JT_LOGISTICS = 'JT_LOGISTICS'

    TRUSK = 'TRUSK'

    VIAXPRESS = 'VIAXPRESS'

    DHL_SUPPLYCHAIN_ID = 'DHL_SUPPLYCHAIN_ID'

    ZUELLIGPHARMA_SFTP = 'ZUELLIGPHARMA_SFTP'

    MEEST = 'MEEST'

    TOLL_PRIORITY = 'TOLL_PRIORITY'

    MOTHERSHIP_API = 'MOTHERSHIP_API'

    CAPITAL = 'CAPITAL'

    EUROPAKET_API = 'EUROPAKET_API'

    HFD = 'HFD'

    TOURLINE_REFERENCE = 'TOURLINE_REFERENCE'

    GIO_ECOURIER = 'GIO_ECOURIER'

    CN_LOGISTICS = 'CN_LOGISTICS'

    PANDION = 'PANDION'

    BPOST_API = 'BPOST_API'

    PASSPORTSHIPPING = 'PASSPORTSHIPPING'

    PAKAJO = 'PAKAJO'

    DACHSER = 'DACHSER'

    YUSEN_SFTP = 'YUSEN_SFTP'

    SHYPLITE = 'SHYPLITE'

    XYY = 'XYY'

    MWD = 'MWD'

    FAXECARGO = 'FAXECARGO'

    MAZET = 'MAZET'

    FIRST_LOGISTICS_API = 'FIRST_LOGISTICS_API'

    SPRINT_PACK = 'SPRINT_PACK'

    HERMES_DE_FTP = 'HERMES_DE_FTP'

    CONCISE = 'CONCISE'

    KERRY_EXPRESS_TW_API = 'KERRY_EXPRESS_TW_API'

    EWE = 'EWE'

    FASTDESPATCH = 'FASTDESPATCH'

    ABCUSTOM_SFTP = 'ABCUSTOM_SFTP'

    CHAZKI = 'CHAZKI'

    SHIPPIE = 'SHIPPIE'

    GEODIS_API = 'GEODIS_API'

    NAQEL_EXPRESS = 'NAQEL_EXPRESS'

    PAPA_WEBHOOK = 'PAPA_WEBHOOK'

    FORWARDAIR = 'FORWARDAIR'

    DIALOGO_LOGISTICA_API = 'DIALOGO_LOGISTICA_API'

    LALAMOVE_API = 'LALAMOVE_API'

    TOMYDOOR = 'TOMYDOOR'

    KRONOS_WEBHOOK = 'KRONOS_WEBHOOK'

    JTCARGO = 'JTCARGO'

    T_CAT = 'T_CAT'

    CONCISE_WEBHOOK = 'CONCISE_WEBHOOK'

    TELEPORT_WEBHOOK = 'TELEPORT_WEBHOOK'

    CUSTOMCO_API = 'CUSTOMCO_API'

    SPX_TH = 'SPX_TH'

    BOLLORE_LOGISTICS = 'BOLLORE_LOGISTICS'

    CLICKLINK_SFTP = 'CLICKLINK_SFTP'

    M3LOGISTICS = 'M3LOGISTICS'

    VNPOST_API = 'VNPOST_API'

    AXLEHIRE_FTP = 'AXLEHIRE_FTP'

    SHADOWFAX = 'SHADOWFAX'

    MYHERMES_UK_API = 'MYHERMES_UK_API'

    DAIICHI = 'DAIICHI'

    MENSAJEROSURBANOS_API = 'MENSAJEROSURBANOS_API'

    POLARSPEED = 'POLARSPEED'

    IDEXPRESS_ID = 'IDEXPRESS_ID'

    PAYO = 'PAYO'

    WHISTL_SFTP = 'WHISTL_SFTP'

    INTEX_DE = 'INTEX_DE'

    TRANS2U = 'TRANS2U'

    PRODUCTCAREGROUP_SFTP = 'PRODUCTCAREGROUP_SFTP'

    BIGSMART = 'BIGSMART'

    EXPEDITORS_API_REF = 'EXPEDITORS_API_REF'

    AITWORLDWIDE_API = 'AITWORLDWIDE_API'

    WORLDCOURIER = 'WORLDCOURIER'

    QUIQUP = 'QUIQUP'

    AGEDISS_SFTP = 'AGEDISS_SFTP'

    ANDREANI_API = 'ANDREANI_API'

    CRLEXPRESS = 'CRLEXPRESS'

    SMARTCAT = 'SMARTCAT'

    CROSSFLIGHT = 'CROSSFLIGHT'

    PROCARRIER = 'PROCARRIER'

    DHL_REFERENCE_API = 'DHL_REFERENCE_API'

    SEINO_API = 'SEINO_API'

    WSPEXPRESS = 'WSPEXPRESS'

    KRONOS = 'KRONOS'

    TOTAL_EXPRESS_API = 'TOTAL_EXPRESS_API'

    PARCLL = 'PARCLL'

    XPEDIGO = 'XPEDIGO'

    STAR_TRACK_WEBHOOK = 'STAR_TRACK_WEBHOOK'

    GPOST = 'GPOST'

    UCS = 'UCS'

    DMFGROUP = 'DMFGROUP'

    COORDINADORA_API = 'COORDINADORA_API'

    MARKEN = 'MARKEN'

    NTL = 'NTL'

    REDJEPAKKETJE = 'REDJEPAKKETJE'

    ALLIED_EXPRESS_FTP = 'ALLIED_EXPRESS_FTP'

    MONDIALRELAY_ES = 'MONDIALRELAY_ES'

    NAEKO_FTP = 'NAEKO_FTP'

    MHI = 'MHI'

    SHIPPIFY = 'SHIPPIFY'

    MALCA_AMIT_API = 'MALCA_AMIT_API'

    JTEXPRESS_SG_API = 'JTEXPRESS_SG_API'

    DACHSER_WEB = 'DACHSER_WEB'

    FLIGHTLG = 'FLIGHTLG'

    CAGO = 'CAGO'

    COM1EXPRESS = 'COM1EXPRESS'

    TONAMI_FTP = 'TONAMI_FTP'

    PACKFLEET = 'PACKFLEET'

    PUROLATOR_INTERNATIONAL = 'PUROLATOR_INTERNATIONAL'

    WINESHIPPING_WEBHOOK = 'WINESHIPPING_WEBHOOK'

    DHL_ES_SFTP = 'DHL_ES_SFTP'

    PCHOME_API = 'PCHOME_API'

    CESKAPOSTA_API = 'CESKAPOSTA_API'

    GORUSH = 'GORUSH'

    HOMERUNNER = 'HOMERUNNER'

    AMAZON_ORDER = 'AMAZON_ORDER'

    EFWNOW_API = 'EFWNOW_API'

    CBL_LOGISTICA_API = 'CBL_LOGISTICA_API'

    NIMBUSPOST = 'NIMBUSPOST'

    LOGWIN_LOGISTICS = 'LOGWIN_LOGISTICS'

    NOWLOG_API = 'NOWLOG_API'

    DPD_NL = 'DPD_NL'

    GODEPENDABLE = 'GODEPENDABLE'

    ESDEX = 'ESDEX'

    LOGISYSTEMS_SFTP = 'LOGISYSTEMS_SFTP'

    EXPEDITORS = 'EXPEDITORS'

    SNTGLOBAL_API = 'SNTGLOBAL_API'

    SHIPX = 'SHIPX'

    QINTL_API = 'QINTL_API'

    PACKS = 'PACKS'

    POSTNL_INTERNATIONAL = 'POSTNL_INTERNATIONAL'

    AMAZON_EMAIL_PUSH = 'AMAZON_EMAIL_PUSH'

    DHL_API = 'DHL_API'

    SPX = 'SPX'

    AXLEHIRE = 'AXLEHIRE'

    ICSCOURIER = 'ICSCOURIER'

    DIALOGO_LOGISTICA = 'DIALOGO_LOGISTICA'

    SHUNBANG_EXPRESS = 'SHUNBANG_EXPRESS'

    TCS_API = 'TCS_API'

    SF_EXPRESS_CN = 'SF_EXPRESS_CN'

    PACKETA = 'PACKETA'

    SIC_TELIWAY = 'SIC_TELIWAY'

    MONDIALRELAY_FR = 'MONDIALRELAY_FR'

    INTIME_FTP = 'INTIME_FTP'

    JD_EXPRESS = 'JD_EXPRESS'

    FASTBOX = 'FASTBOX'

    PATHEON = 'PATHEON'

    INDIA_POST = 'INDIA_POST'

    TIPSA_REF = 'TIPSA_REF'

    ECOFREIGHT = 'ECOFREIGHT'

    VOX = 'VOX'

    DIRECTFREIGHT_AU_REF = 'DIRECTFREIGHT_AU_REF'

    BESTTRANSPORT_SFTP = 'BESTTRANSPORT_SFTP'

    AUSTRALIA_POST_API = 'AUSTRALIA_POST_API'

    FRAGILEPAK_SFTP = 'FRAGILEPAK_SFTP'

    FLIPXP = 'FLIPXP'

    VALUE_WEBHOOK = 'VALUE_WEBHOOK'

    DAESHIN = 'DAESHIN'

    SHERPA = 'SHERPA'

    MWD_API = 'MWD_API'

    SMARTKARGO = 'SMARTKARGO'

    DNJ_EXPRESS = 'DNJ_EXPRESS'

    GOPEOPLE = 'GOPEOPLE'

    MYSENDLE_API = 'MYSENDLE_API'

    ARAMEX_API = 'ARAMEX_API'

    PIDGE = 'PIDGE'

    THAIPARCELS = 'THAIPARCELS'

    PANTHER_REFERENCE_API = 'PANTHER_REFERENCE_API'

    POSTAPLUS1 = 'POSTAPLUS'

    BUFFALO = 'BUFFALO'

    U_ENVIOS = 'U_ENVIOS'

    ELITE_CO = 'ELITE_CO'

    BARQEXP = 'BARQEXP'

    ROCHE_INTERNAL_SFTP = 'ROCHE_INTERNAL_SFTP'

    DBSCHENKER_ICELAND = 'DBSCHENKER_ICELAND'

    TNT_FR_REFERENCE = 'TNT_FR_REFERENCE'

    NEWGISTICSAPI = 'NEWGISTICSAPI'

    GLOVO = 'GLOVO'

    GWLOGIS_API = 'GWLOGIS_API'

    SPREETAIL_API = 'SPREETAIL_API'

    MOOVA = 'MOOVA'

    PLYCONGROUP = 'PLYCONGROUP'

    USPS_WEBHOOK = 'USPS_WEBHOOK'

    REIMAGINEDELIVERY = 'REIMAGINEDELIVERY'

    EDF_FTP = 'EDF_FTP'

    DAO365 = 'DAO365'

    BIOCAIR_FTP = 'BIOCAIR_FTP'

    RANSA_WEBHOOK = 'RANSA_WEBHOOK'

    SHIPXPRES = 'SHIPXPRES'

    COURANT_PLUS_API = 'COURANT_PLUS_API'

    SHIPA = 'SHIPA'

    HOMELOGISTICS = 'HOMELOGISTICS'

    DX = 'DX'

    POSTE_ITALIANE_PACCOCELERE = 'POSTE_ITALIANE_PACCOCELERE'

    TOLL_WEBHOOK = 'TOLL_WEBHOOK'

    LCTBR_API = 'LCTBR_API'

    DX_FREIGHT = 'DX_FREIGHT'

    DHL_SFTP = 'DHL_SFTP'

    SHIPROCKET = 'SHIPROCKET'

    UBER_WEBHOOK = 'UBER_WEBHOOK'

    STATOVERNIGHT = 'STATOVERNIGHT'

    BURD = 'BURD'

    FASTSHIP = 'FASTSHIP'

    IBVENTURE_WEBHOOK = 'IBVENTURE_WEBHOOK'

    GATI_KWE_API = 'GATI_KWE_API'

    CRYOPDP_FTP = 'CRYOPDP_FTP'

    HUBBED = 'HUBBED'

    TIPSA_API = 'TIPSA_API'

    ARASKARGO = 'ARASKARGO'

    THIJS_NL = 'THIJS_NL'

    ATSHEALTHCARE_REFERENCE = 'ATSHEALTHCARE_REFERENCE'

    ENUM_99MINUTOS = '99MINUTOS'

    HELLENIC_POST = 'HELLENIC_POST'

    HSM_GLOBAL = 'HSM_GLOBAL'

    MNX = 'MNX'

    NMTRANSFER = 'NMTRANSFER'

    LOGYSTO = 'LOGYSTO'

    INDIA_POST_INT = 'INDIA_POST_INT'

    AMAZON_FBA_SWISHIP_IN = 'AMAZON_FBA_SWISHIP_IN'

    SRT_TRANSPORT = 'SRT_TRANSPORT'

    BOMI = 'BOMI'

    DELIVERR_SFTP = 'DELIVERR_SFTP'

    HSDEXPRESS = 'HSDEXPRESS'

    SIMPLETIRE_WEBHOOK = 'SIMPLETIRE_WEBHOOK'

    HUNTER_EXPRESS_SFTP = 'HUNTER_EXPRESS_SFTP'

    UPS_API = 'UPS_API'

    WOOYOUNG_LOGISTICS_SFTP = 'WOOYOUNG_LOGISTICS_SFTP'

    PHSE_API = 'PHSE_API'

    WISH_EMAIL_PUSH = 'WISH_EMAIL_PUSH'

    NORTHLINE = 'NORTHLINE'

    MEDAFRICA = 'MEDAFRICA'

    DPD_AT_SFTP = 'DPD_AT_SFTP'

    ANTERAJA = 'ANTERAJA'

    DHL_GLOBAL_FORWARDING_API = 'DHL_GLOBAL_FORWARDING_API'

    LBCEXPRESS_API = 'LBCEXPRESS_API'

    SIMSGLOBAL = 'SIMSGLOBAL'

    CDLDELIVERS = 'CDLDELIVERS'

    TYP = 'TYP'

    TESTING_COURIER_WEBHOOK = 'TESTING_COURIER_WEBHOOK'

    PANDAGO_API = 'PANDAGO_API'

    ROYAL_MAIL_FTP = 'ROYAL_MAIL_FTP'

    THUNDEREXPRESS = 'THUNDEREXPRESS'

    SECRETLAB_WEBHOOK = 'SECRETLAB_WEBHOOK'

    SETEL = 'SETEL'

    JD_WORLDWIDE = 'JD_WORLDWIDE'

    DPD_RU_API = 'DPD_RU_API'

    ARGENTS_WEBHOOK = 'ARGENTS_WEBHOOK'

    POSTONE = 'POSTONE'

    TUSKLOGISTICS = 'TUSKLOGISTICS'

    RHENUS_UK_API = 'RHENUS_UK_API'

    TAQBIN_SG_API = 'TAQBIN_SG_API'

    INNTRALOG_SFTP = 'INNTRALOG_SFTP'

    DAYROSS = 'DAYROSS'

    CORREOSEXPRESS_API = 'CORREOSEXPRESS_API'

    INTERNATIONAL_SEUR_API = 'INTERNATIONAL_SEUR_API'

    YODEL_API = 'YODEL_API'

    HEROEXPRESS = 'HEROEXPRESS'

    DHL_SUPPLYCHAIN_IN = 'DHL_SUPPLYCHAIN_IN'

    URGENT_CARGUS = 'URGENT_CARGUS'

    FRONTDOORCORP = 'FRONTDOORCORP'

    JTEXPRESS_PH = 'JTEXPRESS_PH'

    PARCELSTARS_WEBHOOK = 'PARCELSTARS_WEBHOOK'

    DPD_SK_SFTP = 'DPD_SK_SFTP'

    MOVIANTO = 'MOVIANTO'

    OZEPARTS_SHIPPING = 'OZEPARTS_SHIPPING'

    KARGOMKOLAY = 'KARGOMKOLAY'

    TRUNKRS = 'TRUNKRS'

    OMNIRPS_WEBHOOK = 'OMNIRPS_WEBHOOK'

    CHILEXPRESS = 'CHILEXPRESS'

    TESTING_COURIER = 'TESTING_COURIER'

    JNE_API = 'JNE_API'

    BJSHOMEDELIVERY_FTP = 'BJSHOMEDELIVERY_FTP'

    DEXPRESS_WEBHOOK = 'DEXPRESS_WEBHOOK'

    USPS_API = 'USPS_API'

    TRANSVIRTUAL = 'TRANSVIRTUAL'

    SOLISTICA_API = 'SOLISTICA_API'

    CHIENVENTURE_WEBHOOK = 'CHIENVENTURE_WEBHOOK'

    DPD_UK_SFTP = 'DPD_UK_SFTP'

    INPOST_UK = 'INPOST_UK'

    JAVIT = 'JAVIT'

    ZTO_DOMESTIC = 'ZTO_DOMESTIC'

    DHL_GT_API = 'DHL_GT_API'

    CEVA_TRACKING = 'CEVA_TRACKING'

    KOMON_EXPRESS = 'KOMON_EXPRESS'

    EASTWESTCOURIER_FTP = 'EASTWESTCOURIER_FTP'

    DANNIAO = 'DANNIAO'

    SPECTRAN = 'SPECTRAN'

    DELIVER_IT = 'DELIVER_IT'

    RELAISCOLIS = 'RELAISCOLIS'

    GLS_SPAIN_API = 'GLS_SPAIN_API'

    POSTPLUS = 'POSTPLUS'

    AIRTERRA = 'AIRTERRA'

    GIO_ECOURIER_API = 'GIO_ECOURIER_API'

    DPD_CH_SFTP = 'DPD_CH_SFTP'

    FEDEX_API = 'FEDEX_API'

    INTERSMARTTRANS = 'INTERSMARTTRANS'

    HERMES_UK_SFTP = 'HERMES_UK_SFTP'

    EXELOT_FTP = 'EXELOT_FTP'

    DHL_PA_API = 'DHL_PA_API'

    VIRTRANSPORT_SFTP = 'VIRTRANSPORT_SFTP'

    WORLDNET = 'WORLDNET'

    INSTABOX_WEBHOOK = 'INSTABOX_WEBHOOK'

    KNG = 'KNG'

    FLASHEXPRESS_WEBHOOK = 'FLASHEXPRESS_WEBHOOK'

    MAGYAR_POSTA_API = 'MAGYAR_POSTA_API'

    WESHIP_API = 'WESHIP_API'

    OHI_WEBHOOK = 'OHI_WEBHOOK'

    MUDITA = 'MUDITA'

    BLUEDART_API = 'BLUEDART_API'

    T_CAT_API = 'T_CAT_API'

    ADS = 'ADS'

    HERMES_IT = 'HERMES_IT'

    FITZMARK_API = 'FITZMARK_API'

    POSTI_API = 'POSTI_API'

    SMSA_EXPRESS_WEBHOOK = 'SMSA_EXPRESS_WEBHOOK'

    TAMERGROUP_WEBHOOK = 'TAMERGROUP_WEBHOOK'

    LIVRAPIDE = 'LIVRAPIDE'

    NIPPON_EXPRESS = 'NIPPON_EXPRESS'

    BETTERTRUCKS = 'BETTERTRUCKS'

    FAN = 'FAN'

    PB_USPSFLATS_FTP = 'PB_USPSFLATS_FTP'

    PARCELRIGHT = 'PARCELRIGHT'

    ITHINKLOGISTICS = 'ITHINKLOGISTICS'

    KERRY_EXPRESS_TH_WEBHOOK = 'KERRY_EXPRESS_TH_WEBHOOK'

    ECOUTIER = 'ECOUTIER'

    SHOWL = 'SHOWL'

    BRT_IT_API = 'BRT_IT_API'

    RIXONHK_API = 'RIXONHK_API'

    DBSCHENKER_API = 'DBSCHENKER_API'

    ILYANGLOGIS = 'ILYANGLOGIS'

    MAIL_BOX_ETC = 'MAIL_BOX_ETC'

    WESHIP = 'WESHIP'

    DHL_GLOBAL_MAIL_API = 'DHL_GLOBAL_MAIL_API'

    ACTIVOS24_API = 'ACTIVOS24_API'

    ATSHEALTHCARE = 'ATSHEALTHCARE'

    LUWJISTIK = 'LUWJISTIK'

    GW_WORLD = 'GW_WORLD'

    FAIRSENDEN_API = 'FAIRSENDEN_API'

    SERVIP_WEBHOOK = 'SERVIP_WEBHOOK'

    SWISHIP = 'SWISHIP'

    TANET = 'TANET'

    HOTSIN_CARGO = 'HOTSIN_CARGO'

    DIREX = 'DIREX'

    HUANTONG = 'HUANTONG'

    IMILE_API = 'IMILE_API'

    BDMNET = 'BDMNET'

    AUEXPRESS = 'AUEXPRESS'

    NYTLOGISTICS = 'NYTLOGISTICS'

    DSV_REFERENCE = 'DSV_REFERENCE'

    NOVOFARMA_WEBHOOK = 'NOVOFARMA_WEBHOOK'

    AITWORLDWIDE_SFTP = 'AITWORLDWIDE_SFTP'

    SHOPOLIVE = 'SHOPOLIVE'

    FNF_ZA = 'FNF_ZA'

    DHL_ECOMMERCE_GC = 'DHL_ECOMMERCE_GC'

    FETCHR = 'FETCHR'

    STARLINKS_API = 'STARLINKS_API'

    YYEXPRESS = 'YYEXPRESS'

    SERVIENTREGA = 'SERVIENTREGA'

    HANJIN = 'HANJIN'

    SPANISH_SEUR_FTP = 'SPANISH_SEUR_FTP'

    DX_B2B_CONNUM = 'DX_B2B_CONNUM'

    HELTHJEM_API = 'HELTHJEM_API'

    INEXPOST = 'INEXPOST'

    A2B_BA = 'A2B_BA'

    RHENUS_GROUP = 'RHENUS_GROUP'

    SBERLOGISTICS_RU = 'SBERLOGISTICS_RU'

    MALCA_AMIT = 'MALCA_AMIT'

    PPL = 'PPL'

    OSM_WORLDWIDE_SFTP = 'OSM_WORLDWIDE_SFTP'

    ACILOGISTIX = 'ACILOGISTIX'

    OPTIMACOURIER = 'OPTIMACOURIER'

    NOVA_POSHTA_API = 'NOVA_POSHTA_API'

    LOGGI = 'LOGGI'

    YIFAN = 'YIFAN'

    MYDYNALOGIC = 'MYDYNALOGIC'

    MORNINGLOBAL = 'MORNINGLOBAL'

    CONCISE_API = 'CONCISE_API'

    FXTRAN = 'FXTRAN'

    DELIVERYOURPARCEL_ZA = 'DELIVERYOURPARCEL_ZA'

    UPARCEL = 'UPARCEL'

    MOBI_BR = 'MOBI_BR'

    LOGINEXT_WEBHOOK = 'LOGINEXT_WEBHOOK'

    EMS = 'EMS'

    SPEEDY = 'SPEEDY'

