# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class UPCType(object):

    """Implementation of the 'UPC Type' enum.

    The Universal Product Code type.

    Attributes:
        UPCA: TODO: type description here.
        UPCB: TODO: type description here.
        UPCC: TODO: type description here.
        UPCD: TODO: type description here.
        UPCE: TODO: type description here.
        UPC2: TODO: type description here.
        UPC5: TODO: type description here.

    """
    UPCA = 'UPC-A'

    UPCB = 'UPC-B'

    UPCC = 'UPC-C'

    UPCD = 'UPC-D'

    UPCE = 'UPC-E'

    UPC2 = 'UPC-2'

    UPC5 = 'UPC-5'

