# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaymentAdviceCode(object):

    """Implementation of the 'Payment Advice Code' enum.

    The declined payment transactions might have payment advice codes. The
    card networks, like Visa and Mastercard, return payment advice codes.

    Attributes:
        ENUM_01: TODO: type description here.
        ENUM_02: TODO: type description here.
        ENUM_03: TODO: type description here.
        ENUM_21: TODO: type description here.

    """
    ENUM_01 = '01'

    ENUM_02 = '02'

    ENUM_03 = '03'

    ENUM_21 = '21'

