# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VenmoPaymentTokenCustomerType(object):

    """Implementation of the 'Venmo Payment Token Customer Type' enum.

    The customer type associated with the Venmo payment token. This is to
    indicate whether the customer acting on the merchant / platform is either
    a business or a consumer.

    Attributes:
        CONSUMER: TODO: type description here.
        BUSINESS: TODO: type description here.

    """
    CONSUMER = 'CONSUMER'

    BUSINESS = 'BUSINESS'

