# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FullfillmentType(object):

    """Implementation of the 'Fullfillment Type' enum.

    A classification for the method of purchase fulfillment (e.g shipping,
    in-store pickup, etc). Either `type` or `options` may be present, but not
    both.

    Attributes:
        SHIPPING: TODO: type description here.
        PICKUP_IN_PERSON: TODO: type description here.
        PICKUP_IN_STORE: TODO: type description here.
        PICKUP_FROM_PERSON: TODO: type description here.

    """
    SHIPPING = 'SHIPPING'

    PICKUP_IN_PERSON = 'PICKUP_IN_PERSON'

    PICKUP_IN_STORE = 'PICKUP_IN_STORE'

    PICKUP_FROM_PERSON = 'PICKUP_FROM_PERSON'

