# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderStatus(object):

    """Implementation of the 'Order Status' enum.

    The order status.

    Attributes:
        CREATED: TODO: type description here.
        SAVED: TODO: type description here.
        APPROVED: TODO: type description here.
        VOIDED: TODO: type description here.
        COMPLETED: TODO: type description here.
        PAYER_ACTION_REQUIRED: TODO: type description here.

    """
    CREATED = 'CREATED'

    SAVED = 'SAVED'

    APPROVED = 'APPROVED'

    VOIDED = 'VOIDED'

    COMPLETED = 'COMPLETED'

    PAYER_ACTION_REQUIRED = 'PAYER_ACTION_REQUIRED'

