# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RefundIncompleteReason(object):

    """Implementation of the 'Refund Incomplete Reason' enum.

    The reason why the refund has the `PENDING` or `FAILED` status.

    Attributes:
        ECHECK: TODO: type description here.

    """
    ECHECK = 'ECHECK'

