# -*- coding: utf-8 -*-

"""
paypalserversdk

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderTrackerStatus(object):

    """Implementation of the 'Order Tracker Status' enum.

    The status of the item shipment.

    Attributes:
        CANCELLED: TODO: type description here.
        SHIPPED: TODO: type description here.

    """
    CANCELLED = 'CANCELLED'

    SHIPPED = 'SHIPPED'

